From 0a10fc54bf357cc4ecc228e6a4e88739ffe6b4fb Mon Sep 17 00:00:00 2001 From: Travis CI Date: Thu, 22 Nov 2018 01:43:48 +0000 Subject: [PATCH] Deploy code docs to GitHub Pages Travis build: 435 Commit: a35999f51a0dc547a4fa5312d8b78fb0d970dd5f --- doxygen.log | 4 +- html/classop_1_1_producer.html | 10 +- html/classop_1_1_video_capture_reader.html | 4 +- html/classop_1_1_webcam_reader-members.html | 2 +- html/classop_1_1_webcam_reader.html | 14 +- html/classop_1_1_webcam_reader.js | 2 +- html/flags_8hpp.html | 96 +- html/flags_8hpp.js | 6 +- html/flags_8hpp_source.html | 368 ++-- html/functions_func_w.html | 6 +- html/functions_vars.html | 3 - html/functions_w.html | 15 +- html/globals.html | 2 +- html/globals_func.html | 2 +- html/namespacemembers_c.html | 2 +- html/namespacemembers_func_c.html | 2 +- html/namespaceop.html | 14 +- html/navtree.js | 2 +- html/navtreeindex10.js | 1 - html/navtreeindex5.js | 2 +- html/navtreeindex6.js | 30 +- html/navtreeindex7.js | 6 +- html/navtreeindex8.js | 2 +- html/navtreeindex9.js | 8 +- html/producer_8hpp.html | 4 +- html/producer_8hpp.js | 2 +- html/producer_8hpp_source.html | 6 +- html/search/all_16.js | 23 +- html/search/all_2.js | 2 +- html/search/all_3.js | 4 +- html/search/functions_16.js | 6 +- html/search/functions_2.js | 2 +- html/search/functions_3.js | 4 +- html/search/variables_15.js | 1 - ...ctop_1_1_wrapper_struct_input-members.html | 3 +- html/structop_1_1_wrapper_struct_input.html | 27 +- html/structop_1_1_wrapper_struct_input.js | 5 +- ...top_1_1_wrapper_struct_output-members.html | 2 +- html/structop_1_1_wrapper_struct_output.html | 10 +- html/structop_1_1_wrapper_struct_output.js | 2 +- html/webcam_reader_8hpp_source.html | 43 +- html/wrapper_auxiliary_8hpp_source.html | 1812 +++++++++-------- html/wrapper_struct_input_8hpp_source.html | 39 +- html/wrapper_struct_output_8hpp_source.html | 56 +- 44 files changed, 1312 insertions(+), 1344 deletions(-) diff --git a/doxygen.log b/doxygen.log index a919baee..30425af0 100644 --- a/doxygen.log +++ b/doxygen.log @@ -1141,8 +1141,6 @@ Generating docs for compound op::WHandDetectorTr/home/travis/build/CMU-Perceptua parameter 'type' /home/travis/build/CMU-Perceptual-Computing-Lab/openpose/include/openpose/producer/videoCaptureReader.hpp:19: warning: The following parameters of op::VideoCaptureReader::VideoCaptureReader(const int index, const bool throwExceptionIfNoOpened) are not documented: parameter 'throwExceptionIfNoOpened' -/home/travis/build/CMU-Perceptual-Computing-Lab/openpose/include/openpose/producer/webcamReader.hpp:19: warning: The following parameters of op::WebcamReader::WebcamReader(const int webcamIndex=0, const Point< int > &webcamResolution=Point< int >{}, const double fps=30., const bool throwExceptionIfNoOpened=true) are not documented: - parameter 'throwExceptionIfNoOpened' /home/travis/build/CMU-Perceptual-Computing-Lab/openpose/include/openpose/wrapper/wrapperStructPose.hpp:110: warning: explicit link request to 'body' could not be resolved /home/travis/build/CMU-Perceptual-Computing-Lab/openpose/include/openpose/wrapper/wrapperStructPose.hpp:111: warning: explicit link request to 'body' could not be resolved /home/travis/build/CMU-Perceptual-Computing-Lab/openpose/include/openpose/wrapper/wrapperStructPose.hpp:111: warning: explicit link request to 'body' could not be resolved @@ -1248,5 +1246,5 @@ Generating file index... Generating file member index... Generating example index... finalizing index lists... -lookup cache used 5040/65536 hits=38680 misses=5410 +lookup cache used 5036/65536 hits=38674 misses=5406 finished... diff --git a/html/classop_1_1_producer.html b/html/classop_1_1_producer.html index 85b1e53d..885273ba 100644 --- a/html/classop_1_1_producer.html +++ b/html/classop_1_1_producer.html @@ -369,7 +369,7 @@ Protected Member Functions

It retrieves and returns the camera extrinsic parameters from the frames producer.

Returns
std::vector<cv::Mat> with the camera extrinsic parameters.
-

Implemented in op::ImageDirectoryReader, op::VideoReader, op::WebcamReader, op::FlirReader, and op::IpCameraReader.

+

Implemented in op::ImageDirectoryReader, op::WebcamReader, op::VideoReader, op::FlirReader, and op::IpCameraReader.

@@ -396,7 +396,7 @@ Protected Member Functions

It retrieves and returns the camera intrinsic parameters from the frames producer.

Returns
std::vector<cv::Mat> with the camera intrinsic parameters.
-

Implemented in op::ImageDirectoryReader, op::VideoReader, op::WebcamReader, op::FlirReader, and op::IpCameraReader.

+

Implemented in op::ImageDirectoryReader, op::WebcamReader, op::VideoReader, op::FlirReader, and op::IpCameraReader.

@@ -423,7 +423,7 @@ Protected Member Functions

It retrieves and returns the camera matrixes from the frames producer.

Returns
std::vector<cv::Mat> with the camera matrices.
-

Implemented in op::ImageDirectoryReader, op::VideoReader, op::WebcamReader, op::FlirReader, and op::IpCameraReader.

+

Implemented in op::ImageDirectoryReader, op::WebcamReader, op::VideoReader, op::FlirReader, and op::IpCameraReader.

@@ -484,7 +484,7 @@ Protected Member Functions

This function returns a unique frame name (e.g., the frame number for video, the frame counter for webcam, the image name for image directory reader, etc.).

Returns
std::string with an unique frame name.
-

Implemented in op::ImageDirectoryReader, op::VideoCaptureReader, op::VideoReader, op::WebcamReader, op::FlirReader, and op::IpCameraReader.

+

Implemented in op::ImageDirectoryReader, op::WebcamReader, op::VideoCaptureReader, op::VideoReader, op::FlirReader, and op::IpCameraReader.

@@ -614,7 +614,7 @@ Protected Member Functions

This function returns whether the Producer instance is still opened and able to retrieve more frames.

Returns
bool indicating whether the Producer is opened.
-

Implemented in op::ImageDirectoryReader, op::VideoCaptureReader, op::VideoReader, op::WebcamReader, op::FlirReader, and op::IpCameraReader.

+

Implemented in op::ImageDirectoryReader, op::WebcamReader, op::VideoCaptureReader, op::VideoReader, op::FlirReader, and op::IpCameraReader.

diff --git a/html/classop_1_1_video_capture_reader.html b/html/classop_1_1_video_capture_reader.html index fd374863..093327fa 100644 --- a/html/classop_1_1_video_capture_reader.html +++ b/html/classop_1_1_video_capture_reader.html @@ -352,7 +352,7 @@ Protected Member Functions

Implements op::Producer.

-

Implemented in op::VideoReader, op::WebcamReader, and op::IpCameraReader.

+

Implemented in op::WebcamReader, op::VideoReader, and op::IpCameraReader.

@@ -435,7 +435,7 @@ Protected Member Functions

Implements op::Producer.

-

Reimplemented in op::VideoReader, op::WebcamReader, and op::IpCameraReader.

+

Reimplemented in op::WebcamReader, op::VideoReader, and op::IpCameraReader.

diff --git a/html/classop_1_1_webcam_reader-members.html b/html/classop_1_1_webcam_reader-members.html index e22bdfeb..a5ebfb71 100644 --- a/html/classop_1_1_webcam_reader-members.html +++ b/html/classop_1_1_webcam_reader-members.html @@ -134,7 +134,7 @@ $(document).ready(function(){initNavTree('classop_1_1_webcam_reader.html','');}) setProducerFpsMode(const ProducerFpsMode fpsMode)op::Producer VideoCaptureReader(const int index, const bool throwExceptionIfNoOpened)op::VideoCaptureReaderexplicit VideoCaptureReader(const std::string &path, const ProducerType producerType)op::VideoCaptureReaderexplicit - WebcamReader(const int webcamIndex=0, const Point< int > &webcamResolution=Point< int >{}, const double fps=30., const bool throwExceptionIfNoOpened=true)op::WebcamReaderexplicit + WebcamReader(const int webcamIndex=0, const Point< int > &webcamResolution=Point< int >{}, const bool throwExceptionIfNoOpened=true)op::WebcamReaderexplicit ~Producer()op::Producervirtual ~VideoCaptureReader()op::VideoCaptureReadervirtual ~WebcamReader()op::WebcamReadervirtual diff --git a/html/classop_1_1_webcam_reader.html b/html/classop_1_1_webcam_reader.html index 0fa5f03a..42db012e 100644 --- a/html/classop_1_1_webcam_reader.html +++ b/html/classop_1_1_webcam_reader.html @@ -119,8 +119,8 @@ $(document).ready(function(){initNavTree('classop_1_1_webcam_reader.html','');}) - - + + @@ -182,7 +182,7 @@ Additional Inherited Members

Detailed Description

WebcamReader is a wrapper of the cv::VideoCapture class for webcam. It allows controlling a video (extracting frames, setting resolution & fps, seeking to a particular frame, etc).

Constructor & Destructor Documentation

- +

Public Member Functions

 WebcamReader (const int webcamIndex=0, const Point< int > &webcamResolution=Point< int >{}, const double fps=30., const bool throwExceptionIfNoOpened=true)
 
 WebcamReader (const int webcamIndex=0, const Point< int > &webcamResolution=Point< int >{}, const bool throwExceptionIfNoOpened=true)
 
virtual ~WebcamReader ()
 
std::vector< cv::Mat > getCameraMatrices ()
@@ -201,12 +201,6 @@ Additional Inherited Members - - - - - - @@ -230,7 +224,7 @@ Additional Inherited Members
const Point< int > &  webcamResolution = Point< int >{},
const double fps = 30.,
- +
webcamIndexconst int indicating the camera source (see the OpenCV documentation about cv::VideoCapture for more details), in the range [0, 9].
webcamResolutionconst Point<int> parameter which specifies the desired camera resolution.
fpsDouble parameter which specifies the desired camera frame rate.
throwExceptionIfNoOpenedBool parameter which specifies whether to throw an exception if the camera cannot be opened.
diff --git a/html/classop_1_1_webcam_reader.js b/html/classop_1_1_webcam_reader.js index 7901452f..31bdcf3e 100644 --- a/html/classop_1_1_webcam_reader.js +++ b/html/classop_1_1_webcam_reader.js @@ -1,6 +1,6 @@ var classop_1_1_webcam_reader = [ - [ "WebcamReader", "classop_1_1_webcam_reader.html#afbfa9ebf32ab1c95f0378b49fce0df35", null ], + [ "WebcamReader", "classop_1_1_webcam_reader.html#ab6709f433122e783f87db1004e6666f4", null ], [ "~WebcamReader", "classop_1_1_webcam_reader.html#aea29bfce4df5493d662ed3a892f364d2", null ], [ "get", "classop_1_1_webcam_reader.html#a38ccbdf61f21fba0694362077cb6bdb1", null ], [ "getCameraExtrinsics", "classop_1_1_webcam_reader.html#ab4be6381957df794c76b1c9eddd1f676", null ], diff --git a/html/flags_8hpp.html b/html/flags_8hpp.html index 22f6a5b6..76b1fae5 100644 --- a/html/flags_8hpp.html +++ b/html/flags_8hpp.html @@ -125,8 +125,6 @@ Functions    DEFINE_string (camera_resolution,"-1x-1","Set the camera resolution (either `--camera` or `--flir_camera`). `-1x-1` will use the"" default 1280x720 for `--camera`, or the maximum flir camera resolution available for"" `--flir_camera`")   - DEFINE_double (camera_fps, 30.0,"Frame rate for the webcam (also used when saving video). Set this value to the minimum"" value between the OpenPose displayed speed and the webcam real frame rate.") -   DEFINE_string (video,"","Use a video file instead of the camera. Use `examples/media/video.avi` for our default"" example video.")    DEFINE_string (image_dir,"","Process a directory of images. Use `examples/media/` for our default example folder with 20"" images. Read all standard formats (jpg, png, bmp, etc.).") @@ -255,8 +253,10 @@ Functions    DEFINE_string (write_images_format,"png","File extension and format for `write_images`, e.g., png, jpg or bmp. Check the OpenCV"" function cv::imwrite for all compatible extensions.")   - DEFINE_string (write_video,"","Full file path to write rendered frames in motion JPEG video format. It might fail if the"" final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"" `camera_fps` controls FPS.") -  + DEFINE_string (write_video,"","Full file path to write rendered frames in motion JPEG video format. It might fail if the"" final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"" `write_video_fps` controls FPS.") +  + DEFINE_double (write_video_fps,-1.,"Frame rate for the recorded video. By default, it will try to get the input frames producer"" frame rate (e.g., input video or webcam frame rate). If the input frames producer does not"" have a set FPS (e.g., image_dir or webcam if OpenCV not compiled with its support), set"" this value accordingly (e.g., to the frame rate displayed by the OpenPose GUI).") +   DEFINE_string (write_json,"","Directory to write OpenPose output in JSON format. It includes body, hand, and face pose"" keypoints (2-D and 3-D), as well as pose candidates (if `--part_candidates` enabled).")    DEFINE_string (write_coco_json,"","Full file path to write people pose data with JSON COCO validation format.") @@ -273,8 +273,8 @@ Functions    DEFINE_string (write_keypoint_format,"yml","(Deprecated, use `write_json`) File extension and format for `write_keypoint`: json, xml,"" yaml & yml. Json not available for OpenCV < 3.0, use `write_json` instead.")   - DEFINE_string (write_video_adam,"","Experimental, not available yet. E.g., `~/Desktop/adamResult.avi`. Flag `camera_fps`"" controls FPS.") -  + DEFINE_string (write_video_adam,"","Experimental, not available yet. E.g., `~/Desktop/adamResult.avi`. Flag `write_video_fps`"" controls FPS.") +   DEFINE_string (write_bvh,"","Experimental, not available yet. E.g., `~/Desktop/mocapResult.bvh`.")    DEFINE_string (udp_host,"","Experimental, not available yet. IP for UDP communication. E.g., `192.168.0.1`.") @@ -1095,38 +1095,6 @@ Functions
-
- - -
-
- - - - - - - - - - - - - - - - - - - - - - - - -
DEFINE_double (camera_fps ,
30. 0,
"Frame rate for the webcam (also used when saving video). Set this value to the minimum"" value between the OpenPose displayed speed and the webcam real frame rate."  
)
-
-
@@ -1595,6 +1563,50 @@ Functions
+
+ + +
+
+ + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
DEFINE_double (write_video_fps ,
1.,
"Frame rate for the recorded video. By default,
it will try to get the input frames producer""frame  ratee.g., input video or webcam frame rate).If the input frames producer does not""have a set FPS(e.g., image_dir or webcam if OpenCV not compiled with its support,
set""this value accordingly(e.g., to the frame rate displayed by the OpenPose GUI)."  
)
+
+
@@ -3017,7 +3029,7 @@ Functions - +
@@ -3036,7 +3048,7 @@ Functions - + @@ -3309,7 +3321,7 @@ Functions - +
"Full file path to write rendered frames in motion JPEG video format. It might fail if the"" final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"" `camera_fps` controls FPS." "Full file path to write rendered frames in motion JPEG video format. It might fail if the"" final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"" `write_video_fps` controls FPS."   
@@ -3340,7 +3352,7 @@ Functions - + diff --git a/html/flags_8hpp.js b/html/flags_8hpp.js index 83d55e05..4b3ec119 100644 --- a/html/flags_8hpp.js +++ b/html/flags_8hpp.js @@ -20,7 +20,6 @@ var flags_8hpp = [ "DEFINE_bool", "flags_8hpp.html#a1a9ffc302eac69c8ba024da3edf01a5f", null ], [ "DEFINE_bool", "flags_8hpp.html#a231bec7b2113f31cebb760c849ca2841", null ], [ "DEFINE_bool", "flags_8hpp.html#a0ee4f86d572ef52ec26dcbb37efb5e65", null ], - [ "DEFINE_double", "flags_8hpp.html#a29f9621cd9361deec9512f8d8b53e6ba", null ], [ "DEFINE_double", "flags_8hpp.html#adf35e9261afec1673a42de6197f07f42", null ], [ "DEFINE_double", "flags_8hpp.html#abf5c8a05ae8f86c8e4d8eedbceb84516", null ], [ "DEFINE_double", "flags_8hpp.html#a3a00f877d52f489ed93fb0db8cb8e4dc", null ], @@ -33,6 +32,7 @@ var flags_8hpp = [ "DEFINE_double", "flags_8hpp.html#a890b2b8df8a57fe4e9baa465c6584ccf", null ], [ "DEFINE_double", "flags_8hpp.html#ac17a7af1030d7f5bd69672fec961c083", null ], [ "DEFINE_double", "flags_8hpp.html#a2fe410b6a4ab2577d0f513f5bef78699", null ], + [ "DEFINE_double", "flags_8hpp.html#aba34d451bc7a9409cdb246e1d945b451", null ], [ "DEFINE_int32", "flags_8hpp.html#a73ee51843ead02ee6358fe39dcbeffde", null ], [ "DEFINE_int32", "flags_8hpp.html#a8e9de971b409cfe7fdded7f0d47c502d", null ], [ "DEFINE_int32", "flags_8hpp.html#a10efaeb1ea3a8478388cc7d0bfd4e59e", null ], @@ -68,7 +68,7 @@ var flags_8hpp = [ "DEFINE_string", "flags_8hpp.html#afaf97bbf6a49576782d25147bc865bed", null ], [ "DEFINE_string", "flags_8hpp.html#a7a3597e9216885470199ca1578eb7f69", null ], [ "DEFINE_string", "flags_8hpp.html#a6957bf419a0ca3478948a62a3ce5ecf0", null ], - [ "DEFINE_string", "flags_8hpp.html#a3051d21eb51cc39eed5f781d8eaed960", null ], + [ "DEFINE_string", "flags_8hpp.html#a2473e551c10d8627471382b70fbb838e", null ], [ "DEFINE_string", "flags_8hpp.html#a9aa48b2ab293842bc42b96df9e97c9b8", null ], [ "DEFINE_string", "flags_8hpp.html#a26d1c7340fc87d4593dda754d54145a2", null ], [ "DEFINE_string", "flags_8hpp.html#ac6c2099e630e05f867ee10b43f35dc65", null ], @@ -76,7 +76,7 @@ var flags_8hpp = [ "DEFINE_string", "flags_8hpp.html#a242473077549869f06534e8a9ea1ddd6", null ], [ "DEFINE_string", "flags_8hpp.html#ad8c5173beb83c0f9996362b3a3fba820", null ], [ "DEFINE_string", "flags_8hpp.html#a5aaba99bdb163516d0297d2e09dd0c7d", null ], - [ "DEFINE_string", "flags_8hpp.html#ad7a48143249d608e2ad3a8413eb19c34", null ], + [ "DEFINE_string", "flags_8hpp.html#a26f9e4bae967b528e221c40d21cad543", null ], [ "DEFINE_string", "flags_8hpp.html#a72c09e09c94b67f88b53e1a94e7bfe0f", null ], [ "DEFINE_string", "flags_8hpp.html#a63936bd2bc53a453ba74066289ab9d29", null ], [ "DEFINE_string", "flags_8hpp.html#aa7b1c758c6d6e35c3227994a9ced0236", null ], diff --git a/html/flags_8hpp_source.html b/html/flags_8hpp_source.html index fcac78c6..78ef04cd 100644 --- a/html/flags_8hpp_source.html +++ b/html/flags_8hpp_source.html @@ -142,188 +142,188 @@ $(document).ready(function(){initNavTree('flags_8hpp_source.html','');});
33 DEFINE_string(camera_resolution, "-1x-1", "Set the camera resolution (either `--camera` or `--flir_camera`). `-1x-1` will use the"
34  " default 1280x720 for `--camera`, or the maximum flir camera resolution available for"
35  " `--flir_camera`");
-
36 #endif // OPENPOSE_FLAGS_DISABLE_PRODUCER
-
37 DEFINE_double(camera_fps, 30.0, "Frame rate for the webcam (also used when saving video). Set this value to the minimum"
-
38  " value between the OpenPose displayed speed and the webcam real frame rate.");
-
39 #ifndef OPENPOSE_FLAGS_DISABLE_PRODUCER
-
40 DEFINE_string(video, "", "Use a video file instead of the camera. Use `examples/media/video.avi` for our default"
-
41  " example video.");
-
42 DEFINE_string(image_dir, "", "Process a directory of images. Use `examples/media/` for our default example folder with 20"
-
43  " images. Read all standard formats (jpg, png, bmp, etc.).");
-
44 DEFINE_bool(flir_camera, false, "Whether to use FLIR (Point-Grey) stereo camera.");
-
45 DEFINE_int32(flir_camera_index, -1, "Select -1 (default) to run on all detected flir cameras at once. Otherwise, select the flir"
-
46  " camera index to run, where 0 corresponds to the detected flir camera with the lowest"
-
47  " serial number, and `n` to the `n`-th lowest serial number camera.");
-
48 DEFINE_string(ip_camera, "", "String with the IP camera URL. It supports protocols like RTSP and HTTP.");
-
49 DEFINE_uint64(frame_first, 0, "Start on desired frame number. Indexes are 0-based, i.e., the first frame has index 0.");
-
50 DEFINE_uint64(frame_step, 1, "Step or gap between processed frames. E.g., `--frame_step 5` would read and process frames"
-
51  " 0, 5, 10, etc..");
-
52 DEFINE_uint64(frame_last, -1, "Finish on desired frame number. Select -1 to disable. Indexes are 0-based, e.g., if set to"
-
53  " 10, it will process 11 frames (0-10).");
-
54 DEFINE_bool(frame_flip, false, "Flip/mirror each frame (e.g., for real time webcam demonstrations).");
-
55 DEFINE_int32(frame_rotate, 0, "Rotate each frame, 4 possible values: 0, 90, 180, 270.");
-
56 DEFINE_bool(frames_repeat, false, "Repeat frames when finished.");
-
57 DEFINE_bool(process_real_time, false, "Enable to keep the original source frame rate (e.g., for video). If the processing time is"
-
58  " too long, it will skip frames. If it is too fast, it will slow it down.");
-
59 DEFINE_string(camera_parameter_folder, "models/cameraParameters/flir/", "String with the folder where the camera parameters are located.");
-
60 DEFINE_bool(frame_keep_distortion, false, "If false (default), it will undistortionate the image based on the"
-
61  " `camera_parameter_folder` camera parameters; if true, it will not undistortionate, i.e.,"
-
62  " it will leave it as it is.");
-
63 #endif // OPENPOSE_FLAGS_DISABLE_PRODUCER
-
64 // OpenPose
-
65 DEFINE_string(model_folder, "models/", "Folder path (absolute or relative) where the models (pose, face, ...) are located.");
-
66 DEFINE_string(output_resolution, "-1x-1", "The image resolution (display and output). Use \"-1x-1\" to force the program to use the"
-
67  " input image resolution.");
-
68 DEFINE_int32(num_gpu, -1, "The number of GPU devices to use. If negative, it will use all the available GPUs in your"
-
69  " machine.");
-
70 DEFINE_int32(num_gpu_start, 0, "GPU device start number.");
-
71 DEFINE_int32(keypoint_scale, 0, "Scaling of the (x,y) coordinates of the final pose data array, i.e., the scale of the (x,y)"
-
72  " coordinates that will be saved with the `write_json` & `write_keypoint` flags."
-
73  " Select `0` to scale it to the original source resolution; `1`to scale it to the net output"
-
74  " size (set with `net_resolution`); `2` to scale it to the final output size (set with"
-
75  " `resolution`); `3` to scale it in the range [0,1], where (0,0) would be the top-left"
-
76  " corner of the image, and (1,1) the bottom-right one; and 4 for range [-1,1], where"
-
77  " (-1,-1) would be the top-left corner of the image, and (1,1) the bottom-right one. Non"
-
78  " related with `scale_number` and `scale_gap`.");
-
79 DEFINE_int32(number_people_max, -1, "This parameter will limit the maximum number of people detected, by keeping the people with"
-
80  " top scores. The score is based in person area over the image, body part score, as well as"
-
81  " joint score (between each pair of connected body parts). Useful if you know the exact"
-
82  " number of people in the scene, so it can remove false positives (if all the people have"
-
83  " been detected. However, it might also include false negatives by removing very small or"
-
84  " highly occluded people. -1 will keep them all.");
-
85 DEFINE_bool(maximize_positives, false, "It reduces the thresholds to accept a person candidate. It highly increases both false and"
-
86  " true positives. I.e., it maximizes average recall but could harm average precision.");
-
87 // OpenPose Body Pose
-
88 DEFINE_bool(body_disable, false, "Disable body keypoint detection. Option only possible for faster (but less accurate) face"
-
89  " keypoint detection.");
-
90 DEFINE_string(model_pose, "BODY_25", "Model to be used. E.g., `COCO` (18 keypoints), `MPI` (15 keypoints, ~10% faster), "
-
91  "`MPI_4_layers` (15 keypoints, even faster but less accurate).");
-
92 DEFINE_string(net_resolution, "-1x368", "Multiples of 16. If it is increased, the accuracy potentially increases. If it is"
-
93  " decreased, the speed increases. For maximum speed-accuracy balance, it should keep the"
-
94  " closest aspect ratio possible to the images or videos to be processed. Using `-1` in"
-
95  " any of the dimensions, OP will choose the optimal aspect ratio depending on the user's"
-
96  " input value. E.g., the default `-1x368` is equivalent to `656x368` in 16:9 resolutions,"
-
97  " e.g., full HD (1980x1080) and HD (1280x720) resolutions.");
-
98 DEFINE_int32(scale_number, 1, "Number of scales to average.");
-
99 DEFINE_double(scale_gap, 0.3, "Scale gap between scales. No effect unless scale_number > 1. Initial scale is always 1."
-
100  " If you want to change the initial scale, you actually want to multiply the"
-
101  " `net_resolution` by your desired initial scale.");
-
102 // OpenPose Body Pose Heatmaps and Part Candidates
-
103 DEFINE_bool(heatmaps_add_parts, false, "If true, it will fill op::Datum::poseHeatMaps array with the body part heatmaps, and"
-
104  " analogously face & hand heatmaps to op::Datum::faceHeatMaps & op::Datum::handHeatMaps."
-
105  " If more than one `add_heatmaps_X` flag is enabled, it will place then in sequential"
-
106  " memory order: body parts + bkg + PAFs. It will follow the order on"
-
107  " POSE_BODY_PART_MAPPING in `src/openpose/pose/poseParameters.cpp`. Program speed will"
-
108  " considerably decrease. Not required for OpenPose, enable it only if you intend to"
-
109  " explicitly use this information later.");
-
110 DEFINE_bool(heatmaps_add_bkg, false, "Same functionality as `add_heatmaps_parts`, but adding the heatmap corresponding to"
-
111  " background.");
-
112 DEFINE_bool(heatmaps_add_PAFs, false, "Same functionality as `add_heatmaps_parts`, but adding the PAFs.");
-
113 DEFINE_int32(heatmaps_scale, 2, "Set 0 to scale op::Datum::poseHeatMaps in the range [-1,1], 1 for [0,1]; 2 for integer"
-
114  " rounded [0,255]; and 3 for no scaling.");
-
115 DEFINE_bool(part_candidates, false, "Also enable `write_json` in order to save this information. If true, it will fill the"
-
116  " op::Datum::poseCandidates array with the body part candidates. Candidates refer to all"
-
117  " the detected body parts, before being assembled into people. Note that the number of"
-
118  " candidates is equal or higher than the number of final body parts (i.e., after being"
-
119  " assembled into people). The empty body parts are filled with 0s. Program speed will"
-
120  " slightly decrease. Not required for OpenPose, enable it only if you intend to explicitly"
-
121  " use this information.");
-
122 // OpenPose Face
-
123 DEFINE_bool(face, false, "Enables face keypoint detection. It will share some parameters from the body pose, e.g."
-
124  " `model_folder`. Note that this will considerable slow down the performance and increse"
-
125  " the required GPU memory. In addition, the greater number of people on the image, the"
-
126  " slower OpenPose will be.");
-
127 DEFINE_string(face_net_resolution, "368x368", "Multiples of 16 and squared. Analogous to `net_resolution` but applied to the face keypoint"
-
128  " detector. 320x320 usually works fine while giving a substantial speed up when multiple"
-
129  " faces on the image.");
-
130 // OpenPose Hand
-
131 DEFINE_bool(hand, false, "Enables hand keypoint detection. It will share some parameters from the body pose, e.g."
-
132  " `model_folder`. Analogously to `--face`, it will also slow down the performance, increase"
-
133  " the required GPU memory and its speed depends on the number of people.");
-
134 DEFINE_string(hand_net_resolution, "368x368", "Multiples of 16 and squared. Analogous to `net_resolution` but applied to the hand keypoint"
-
135  " detector.");
-
136 DEFINE_int32(hand_scale_number, 1, "Analogous to `scale_number` but applied to the hand keypoint detector. Our best results"
-
137  " were found with `hand_scale_number` = 6 and `hand_scale_range` = 0.4.");
-
138 DEFINE_double(hand_scale_range, 0.4, "Analogous purpose than `scale_gap` but applied to the hand keypoint detector. Total range"
-
139  " between smallest and biggest scale. The scales will be centered in ratio 1. E.g., if"
-
140  " scaleRange = 0.4 and scalesNumber = 2, then there will be 2 scales, 0.8 and 1.2.");
-
141 DEFINE_bool(hand_tracking, false, "Adding hand tracking might improve hand keypoints detection for webcam (if the frame rate"
-
142  " is high enough, i.e., >7 FPS per GPU) and video. This is not person ID tracking, it"
-
143  " simply looks for hands in positions at which hands were located in previous frames, but"
-
144  " it does not guarantee the same person ID among frames.");
-
145 // OpenPose 3-D Reconstruction
-
146 DEFINE_bool(3d, false, "Running OpenPose 3-D reconstruction demo: 1) Reading from a stereo camera system."
-
147  " 2) Performing 3-D reconstruction from the multiple views. 3) Displaying 3-D reconstruction"
-
148  " results. Note that it will only display 1 person. If multiple people is present, it will"
-
149  " fail.");
-
150 DEFINE_int32(3d_min_views, -1, "Minimum number of views required to reconstruct each keypoint. By default (-1), it will"
-
151  " require all the cameras to see the keypoint in order to reconstruct it.");
-
152 DEFINE_int32(3d_views, 1, "Complementary option to `--image_dir` or `--video`. OpenPose will read as many images per"
-
153  " iteration, allowing tasks such as stereo camera processing (`--3d`). Note that"
-
154  " `--camera_parameters_folder` must be set. OpenPose must find as many `xml` files in the"
-
155  " parameter folder as this number indicates.");
-
156 // Extra algorithms
-
157 DEFINE_bool(identification, false, "Experimental, not available yet. Whether to enable people identification across frames.");
-
158 DEFINE_int32(tracking, -1, "Experimental, not available yet. Whether to enable people tracking across frames. The"
-
159  " value indicates the number of frames where tracking is run between each OpenPose keypoint"
-
160  " detection. Select -1 (default) to disable it or 0 to run simultaneously OpenPose keypoint"
-
161  " detector and tracking for potentially higher accurary than only OpenPose.");
-
162 DEFINE_int32(ik_threads, 0, "Experimental, not available yet. Whether to enable inverse kinematics (IK) from 3-D"
-
163  " keypoints to obtain 3-D joint angles. By default (0 threads), it is disabled. Increasing"
-
164  " the number of threads will increase the speed but also the global system latency.");
-
165 // OpenPose Rendering
-
166 DEFINE_int32(part_to_show, 0, "Prediction channel to visualize (default: 0). 0 for all the body parts, 1-18 for each body"
-
167  " part heat map, 19 for the background heat map, 20 for all the body part heat maps"
-
168  " together, 21 for all the PAFs, 22-40 for each body part pair PAF.");
-
169 DEFINE_bool(disable_blending, false, "If enabled, it will render the results (keypoint skeletons or heatmaps) on a black"
-
170  " background, instead of being rendered into the original image. Related: `part_to_show`,"
-
171  " `alpha_pose`, and `alpha_pose`.");
-
172 // OpenPose Rendering Pose
-
173 DEFINE_double(render_threshold, 0.05, "Only estimated keypoints whose score confidences are higher than this threshold will be"
-
174  " rendered. Generally, a high threshold (> 0.5) will only render very clear body parts;"
-
175  " while small thresholds (~0.1) will also output guessed and occluded keypoints, but also"
-
176  " more false positives (i.e., wrong detections).");
-
177 DEFINE_int32(render_pose, -1, "Set to 0 for no rendering, 1 for CPU rendering (slightly faster), and 2 for GPU rendering"
-
178  " (slower but greater functionality, e.g., `alpha_X` flags). If -1, it will pick CPU if"
-
179  " CPU_ONLY is enabled, or GPU if CUDA is enabled. If rendering is enabled, it will render"
-
180  " both `outputData` and `cvOutputData` with the original image and desired body part to be"
-
181  " shown (i.e., keypoints, heat maps or PAFs).");
-
182 DEFINE_double(alpha_pose, 0.6, "Blending factor (range 0-1) for the body part rendering. 1 will show it completely, 0 will"
-
183  " hide it. Only valid for GPU rendering.");
-
184 DEFINE_double(alpha_heatmap, 0.7, "Blending factor (range 0-1) between heatmap and original frame. 1 will only show the"
-
185  " heatmap, 0 will only show the frame. Only valid for GPU rendering.");
-
186 // OpenPose Rendering Face
-
187 DEFINE_double(face_render_threshold, 0.4, "Analogous to `render_threshold`, but applied to the face keypoints.");
-
188 DEFINE_int32(face_render, -1, "Analogous to `render_pose` but applied to the face. Extra option: -1 to use the same"
-
189  " configuration that `render_pose` is using.");
-
190 DEFINE_double(face_alpha_pose, 0.6, "Analogous to `alpha_pose` but applied to face.");
-
191 DEFINE_double(face_alpha_heatmap, 0.7, "Analogous to `alpha_heatmap` but applied to face.");
-
192 // OpenPose Rendering Hand
-
193 DEFINE_double(hand_render_threshold, 0.2, "Analogous to `render_threshold`, but applied to the hand keypoints.");
-
194 DEFINE_int32(hand_render, -1, "Analogous to `render_pose` but applied to the hand. Extra option: -1 to use the same"
-
195  " configuration that `render_pose` is using.");
-
196 DEFINE_double(hand_alpha_pose, 0.6, "Analogous to `alpha_pose` but applied to hand.");
-
197 DEFINE_double(hand_alpha_heatmap, 0.7, "Analogous to `alpha_heatmap` but applied to hand.");
-
198 #ifndef OPENPOSE_FLAGS_DISABLE_DISPLAY
-
199 // Display
-
200 DEFINE_bool(fullscreen, false, "Run in full-screen mode (press f during runtime to toggle).");
-
201 DEFINE_bool(no_gui_verbose, false, "Do not write text on output images on GUI (e.g., number of current frame and people). It"
-
202  " does not affect the pose rendering.");
-
203 DEFINE_int32(display, -1, "Display mode: -1 for automatic selection; 0 for no display (useful if there is no X server"
-
204  " and/or to slightly speed up the processing if visual output is not required); 2 for 2-D"
-
205  " display; 3 for 3-D display (if `--3d` enabled); and 1 for both 2-D and 3-D display.");
-
206 #endif // OPENPOSE_FLAGS_DISABLE_DISPLAY
-
207 // Command Line Interface Verbose
-
208 DEFINE_double(cli_verbose, -1.f, "If -1, it will be disabled (default). If it is a positive integer number, it will print on"
-
209  " the command line every `verbose` frames. If number in the range (0,1), it will print the"
-
210  " progress every `verbose` times the total of frames.");
-
211 // Result Saving
-
212 DEFINE_string(write_images, "", "Directory to write rendered frames in `write_images_format` image format.");
-
213 DEFINE_string(write_images_format, "png", "File extension and format for `write_images`, e.g., png, jpg or bmp. Check the OpenCV"
-
214  " function cv::imwrite for all compatible extensions.");
-
215 DEFINE_string(write_video, "", "Full file path to write rendered frames in motion JPEG video format. It might fail if the"
-
216  " final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"
-
217  " `camera_fps` controls FPS.");
+
36 DEFINE_string(video, "", "Use a video file instead of the camera. Use `examples/media/video.avi` for our default"
+
37  " example video.");
+
38 DEFINE_string(image_dir, "", "Process a directory of images. Use `examples/media/` for our default example folder with 20"
+
39  " images. Read all standard formats (jpg, png, bmp, etc.).");
+
40 DEFINE_bool(flir_camera, false, "Whether to use FLIR (Point-Grey) stereo camera.");
+
41 DEFINE_int32(flir_camera_index, -1, "Select -1 (default) to run on all detected flir cameras at once. Otherwise, select the flir"
+
42  " camera index to run, where 0 corresponds to the detected flir camera with the lowest"
+
43  " serial number, and `n` to the `n`-th lowest serial number camera.");
+
44 DEFINE_string(ip_camera, "", "String with the IP camera URL. It supports protocols like RTSP and HTTP.");
+
45 DEFINE_uint64(frame_first, 0, "Start on desired frame number. Indexes are 0-based, i.e., the first frame has index 0.");
+
46 DEFINE_uint64(frame_step, 1, "Step or gap between processed frames. E.g., `--frame_step 5` would read and process frames"
+
47  " 0, 5, 10, etc..");
+
48 DEFINE_uint64(frame_last, -1, "Finish on desired frame number. Select -1 to disable. Indexes are 0-based, e.g., if set to"
+
49  " 10, it will process 11 frames (0-10).");
+
50 DEFINE_bool(frame_flip, false, "Flip/mirror each frame (e.g., for real time webcam demonstrations).");
+
51 DEFINE_int32(frame_rotate, 0, "Rotate each frame, 4 possible values: 0, 90, 180, 270.");
+
52 DEFINE_bool(frames_repeat, false, "Repeat frames when finished.");
+
53 DEFINE_bool(process_real_time, false, "Enable to keep the original source frame rate (e.g., for video). If the processing time is"
+
54  " too long, it will skip frames. If it is too fast, it will slow it down.");
+
55 DEFINE_string(camera_parameter_folder, "models/cameraParameters/flir/", "String with the folder where the camera parameters are located.");
+
56 DEFINE_bool(frame_keep_distortion, false, "If false (default), it will undistortionate the image based on the"
+
57  " `camera_parameter_folder` camera parameters; if true, it will not undistortionate, i.e.,"
+
58  " it will leave it as it is.");
+
59 #endif // OPENPOSE_FLAGS_DISABLE_PRODUCER
+
60 // OpenPose
+
61 DEFINE_string(model_folder, "models/", "Folder path (absolute or relative) where the models (pose, face, ...) are located.");
+
62 DEFINE_string(output_resolution, "-1x-1", "The image resolution (display and output). Use \"-1x-1\" to force the program to use the"
+
63  " input image resolution.");
+
64 DEFINE_int32(num_gpu, -1, "The number of GPU devices to use. If negative, it will use all the available GPUs in your"
+
65  " machine.");
+
66 DEFINE_int32(num_gpu_start, 0, "GPU device start number.");
+
67 DEFINE_int32(keypoint_scale, 0, "Scaling of the (x,y) coordinates of the final pose data array, i.e., the scale of the (x,y)"
+
68  " coordinates that will be saved with the `write_json` & `write_keypoint` flags."
+
69  " Select `0` to scale it to the original source resolution; `1`to scale it to the net output"
+
70  " size (set with `net_resolution`); `2` to scale it to the final output size (set with"
+
71  " `resolution`); `3` to scale it in the range [0,1], where (0,0) would be the top-left"
+
72  " corner of the image, and (1,1) the bottom-right one; and 4 for range [-1,1], where"
+
73  " (-1,-1) would be the top-left corner of the image, and (1,1) the bottom-right one. Non"
+
74  " related with `scale_number` and `scale_gap`.");
+
75 DEFINE_int32(number_people_max, -1, "This parameter will limit the maximum number of people detected, by keeping the people with"
+
76  " top scores. The score is based in person area over the image, body part score, as well as"
+
77  " joint score (between each pair of connected body parts). Useful if you know the exact"
+
78  " number of people in the scene, so it can remove false positives (if all the people have"
+
79  " been detected. However, it might also include false negatives by removing very small or"
+
80  " highly occluded people. -1 will keep them all.");
+
81 DEFINE_bool(maximize_positives, false, "It reduces the thresholds to accept a person candidate. It highly increases both false and"
+
82  " true positives. I.e., it maximizes average recall but could harm average precision.");
+
83 // OpenPose Body Pose
+
84 DEFINE_bool(body_disable, false, "Disable body keypoint detection. Option only possible for faster (but less accurate) face"
+
85  " keypoint detection.");
+
86 DEFINE_string(model_pose, "BODY_25", "Model to be used. E.g., `COCO` (18 keypoints), `MPI` (15 keypoints, ~10% faster), "
+
87  "`MPI_4_layers` (15 keypoints, even faster but less accurate).");
+
88 DEFINE_string(net_resolution, "-1x368", "Multiples of 16. If it is increased, the accuracy potentially increases. If it is"
+
89  " decreased, the speed increases. For maximum speed-accuracy balance, it should keep the"
+
90  " closest aspect ratio possible to the images or videos to be processed. Using `-1` in"
+
91  " any of the dimensions, OP will choose the optimal aspect ratio depending on the user's"
+
92  " input value. E.g., the default `-1x368` is equivalent to `656x368` in 16:9 resolutions,"
+
93  " e.g., full HD (1980x1080) and HD (1280x720) resolutions.");
+
94 DEFINE_int32(scale_number, 1, "Number of scales to average.");
+
95 DEFINE_double(scale_gap, 0.3, "Scale gap between scales. No effect unless scale_number > 1. Initial scale is always 1."
+
96  " If you want to change the initial scale, you actually want to multiply the"
+
97  " `net_resolution` by your desired initial scale.");
+
98 // OpenPose Body Pose Heatmaps and Part Candidates
+
99 DEFINE_bool(heatmaps_add_parts, false, "If true, it will fill op::Datum::poseHeatMaps array with the body part heatmaps, and"
+
100  " analogously face & hand heatmaps to op::Datum::faceHeatMaps & op::Datum::handHeatMaps."
+
101  " If more than one `add_heatmaps_X` flag is enabled, it will place then in sequential"
+
102  " memory order: body parts + bkg + PAFs. It will follow the order on"
+
103  " POSE_BODY_PART_MAPPING in `src/openpose/pose/poseParameters.cpp`. Program speed will"
+
104  " considerably decrease. Not required for OpenPose, enable it only if you intend to"
+
105  " explicitly use this information later.");
+
106 DEFINE_bool(heatmaps_add_bkg, false, "Same functionality as `add_heatmaps_parts`, but adding the heatmap corresponding to"
+
107  " background.");
+
108 DEFINE_bool(heatmaps_add_PAFs, false, "Same functionality as `add_heatmaps_parts`, but adding the PAFs.");
+
109 DEFINE_int32(heatmaps_scale, 2, "Set 0 to scale op::Datum::poseHeatMaps in the range [-1,1], 1 for [0,1]; 2 for integer"
+
110  " rounded [0,255]; and 3 for no scaling.");
+
111 DEFINE_bool(part_candidates, false, "Also enable `write_json` in order to save this information. If true, it will fill the"
+
112  " op::Datum::poseCandidates array with the body part candidates. Candidates refer to all"
+
113  " the detected body parts, before being assembled into people. Note that the number of"
+
114  " candidates is equal or higher than the number of final body parts (i.e., after being"
+
115  " assembled into people). The empty body parts are filled with 0s. Program speed will"
+
116  " slightly decrease. Not required for OpenPose, enable it only if you intend to explicitly"
+
117  " use this information.");
+
118 // OpenPose Face
+
119 DEFINE_bool(face, false, "Enables face keypoint detection. It will share some parameters from the body pose, e.g."
+
120  " `model_folder`. Note that this will considerable slow down the performance and increse"
+
121  " the required GPU memory. In addition, the greater number of people on the image, the"
+
122  " slower OpenPose will be.");
+
123 DEFINE_string(face_net_resolution, "368x368", "Multiples of 16 and squared. Analogous to `net_resolution` but applied to the face keypoint"
+
124  " detector. 320x320 usually works fine while giving a substantial speed up when multiple"
+
125  " faces on the image.");
+
126 // OpenPose Hand
+
127 DEFINE_bool(hand, false, "Enables hand keypoint detection. It will share some parameters from the body pose, e.g."
+
128  " `model_folder`. Analogously to `--face`, it will also slow down the performance, increase"
+
129  " the required GPU memory and its speed depends on the number of people.");
+
130 DEFINE_string(hand_net_resolution, "368x368", "Multiples of 16 and squared. Analogous to `net_resolution` but applied to the hand keypoint"
+
131  " detector.");
+
132 DEFINE_int32(hand_scale_number, 1, "Analogous to `scale_number` but applied to the hand keypoint detector. Our best results"
+
133  " were found with `hand_scale_number` = 6 and `hand_scale_range` = 0.4.");
+
134 DEFINE_double(hand_scale_range, 0.4, "Analogous purpose than `scale_gap` but applied to the hand keypoint detector. Total range"
+
135  " between smallest and biggest scale. The scales will be centered in ratio 1. E.g., if"
+
136  " scaleRange = 0.4 and scalesNumber = 2, then there will be 2 scales, 0.8 and 1.2.");
+
137 DEFINE_bool(hand_tracking, false, "Adding hand tracking might improve hand keypoints detection for webcam (if the frame rate"
+
138  " is high enough, i.e., >7 FPS per GPU) and video. This is not person ID tracking, it"
+
139  " simply looks for hands in positions at which hands were located in previous frames, but"
+
140  " it does not guarantee the same person ID among frames.");
+
141 // OpenPose 3-D Reconstruction
+
142 DEFINE_bool(3d, false, "Running OpenPose 3-D reconstruction demo: 1) Reading from a stereo camera system."
+
143  " 2) Performing 3-D reconstruction from the multiple views. 3) Displaying 3-D reconstruction"
+
144  " results. Note that it will only display 1 person. If multiple people is present, it will"
+
145  " fail.");
+
146 DEFINE_int32(3d_min_views, -1, "Minimum number of views required to reconstruct each keypoint. By default (-1), it will"
+
147  " require all the cameras to see the keypoint in order to reconstruct it.");
+
148 DEFINE_int32(3d_views, 1, "Complementary option to `--image_dir` or `--video`. OpenPose will read as many images per"
+
149  " iteration, allowing tasks such as stereo camera processing (`--3d`). Note that"
+
150  " `--camera_parameters_folder` must be set. OpenPose must find as many `xml` files in the"
+
151  " parameter folder as this number indicates.");
+
152 // Extra algorithms
+
153 DEFINE_bool(identification, false, "Experimental, not available yet. Whether to enable people identification across frames.");
+
154 DEFINE_int32(tracking, -1, "Experimental, not available yet. Whether to enable people tracking across frames. The"
+
155  " value indicates the number of frames where tracking is run between each OpenPose keypoint"
+
156  " detection. Select -1 (default) to disable it or 0 to run simultaneously OpenPose keypoint"
+
157  " detector and tracking for potentially higher accurary than only OpenPose.");
+
158 DEFINE_int32(ik_threads, 0, "Experimental, not available yet. Whether to enable inverse kinematics (IK) from 3-D"
+
159  " keypoints to obtain 3-D joint angles. By default (0 threads), it is disabled. Increasing"
+
160  " the number of threads will increase the speed but also the global system latency.");
+
161 // OpenPose Rendering
+
162 DEFINE_int32(part_to_show, 0, "Prediction channel to visualize (default: 0). 0 for all the body parts, 1-18 for each body"
+
163  " part heat map, 19 for the background heat map, 20 for all the body part heat maps"
+
164  " together, 21 for all the PAFs, 22-40 for each body part pair PAF.");
+
165 DEFINE_bool(disable_blending, false, "If enabled, it will render the results (keypoint skeletons or heatmaps) on a black"
+
166  " background, instead of being rendered into the original image. Related: `part_to_show`,"
+
167  " `alpha_pose`, and `alpha_pose`.");
+
168 // OpenPose Rendering Pose
+
169 DEFINE_double(render_threshold, 0.05, "Only estimated keypoints whose score confidences are higher than this threshold will be"
+
170  " rendered. Generally, a high threshold (> 0.5) will only render very clear body parts;"
+
171  " while small thresholds (~0.1) will also output guessed and occluded keypoints, but also"
+
172  " more false positives (i.e., wrong detections).");
+
173 DEFINE_int32(render_pose, -1, "Set to 0 for no rendering, 1 for CPU rendering (slightly faster), and 2 for GPU rendering"
+
174  " (slower but greater functionality, e.g., `alpha_X` flags). If -1, it will pick CPU if"
+
175  " CPU_ONLY is enabled, or GPU if CUDA is enabled. If rendering is enabled, it will render"
+
176  " both `outputData` and `cvOutputData` with the original image and desired body part to be"
+
177  " shown (i.e., keypoints, heat maps or PAFs).");
+
178 DEFINE_double(alpha_pose, 0.6, "Blending factor (range 0-1) for the body part rendering. 1 will show it completely, 0 will"
+
179  " hide it. Only valid for GPU rendering.");
+
180 DEFINE_double(alpha_heatmap, 0.7, "Blending factor (range 0-1) between heatmap and original frame. 1 will only show the"
+
181  " heatmap, 0 will only show the frame. Only valid for GPU rendering.");
+
182 // OpenPose Rendering Face
+
183 DEFINE_double(face_render_threshold, 0.4, "Analogous to `render_threshold`, but applied to the face keypoints.");
+
184 DEFINE_int32(face_render, -1, "Analogous to `render_pose` but applied to the face. Extra option: -1 to use the same"
+
185  " configuration that `render_pose` is using.");
+
186 DEFINE_double(face_alpha_pose, 0.6, "Analogous to `alpha_pose` but applied to face.");
+
187 DEFINE_double(face_alpha_heatmap, 0.7, "Analogous to `alpha_heatmap` but applied to face.");
+
188 // OpenPose Rendering Hand
+
189 DEFINE_double(hand_render_threshold, 0.2, "Analogous to `render_threshold`, but applied to the hand keypoints.");
+
190 DEFINE_int32(hand_render, -1, "Analogous to `render_pose` but applied to the hand. Extra option: -1 to use the same"
+
191  " configuration that `render_pose` is using.");
+
192 DEFINE_double(hand_alpha_pose, 0.6, "Analogous to `alpha_pose` but applied to hand.");
+
193 DEFINE_double(hand_alpha_heatmap, 0.7, "Analogous to `alpha_heatmap` but applied to hand.");
+
194 #ifndef OPENPOSE_FLAGS_DISABLE_DISPLAY
+
195 // Display
+
196 DEFINE_bool(fullscreen, false, "Run in full-screen mode (press f during runtime to toggle).");
+
197 DEFINE_bool(no_gui_verbose, false, "Do not write text on output images on GUI (e.g., number of current frame and people). It"
+
198  " does not affect the pose rendering.");
+
199 DEFINE_int32(display, -1, "Display mode: -1 for automatic selection; 0 for no display (useful if there is no X server"
+
200  " and/or to slightly speed up the processing if visual output is not required); 2 for 2-D"
+
201  " display; 3 for 3-D display (if `--3d` enabled); and 1 for both 2-D and 3-D display.");
+
202 #endif // OPENPOSE_FLAGS_DISABLE_DISPLAY
+
203 // Command Line Interface Verbose
+
204 DEFINE_double(cli_verbose, -1.f, "If -1, it will be disabled (default). If it is a positive integer number, it will print on"
+
205  " the command line every `verbose` frames. If number in the range (0,1), it will print the"
+
206  " progress every `verbose` times the total of frames.");
+
207 // Result Saving
+
208 DEFINE_string(write_images, "", "Directory to write rendered frames in `write_images_format` image format.");
+
209 DEFINE_string(write_images_format, "png", "File extension and format for `write_images`, e.g., png, jpg or bmp. Check the OpenCV"
+
210  " function cv::imwrite for all compatible extensions.");
+
211 DEFINE_string(write_video, "", "Full file path to write rendered frames in motion JPEG video format. It might fail if the"
+
212  " final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"
+
213  " `write_video_fps` controls FPS.");
+
214 DEFINE_double(write_video_fps, -1., "Frame rate for the recorded video. By default, it will try to get the input frames producer"
+
215  " frame rate (e.g., input video or webcam frame rate). If the input frames producer does not"
+
216  " have a set FPS (e.g., image_dir or webcam if OpenCV not compiled with its support), set"
+
217  " this value accordingly (e.g., to the frame rate displayed by the OpenPose GUI).");
218 DEFINE_string(write_json, "", "Directory to write OpenPose output in JSON format. It includes body, hand, and face pose"
219  " keypoints (2-D and 3-D), as well as pose candidates (if `--part_candidates` enabled).");
220 DEFINE_string(write_coco_json, "", "Full file path to write people pose data with JSON COCO validation format.");
@@ -340,7 +340,7 @@ $(document).ready(function(){initNavTree('flags_8hpp_source.html','');});
231 DEFINE_string(write_keypoint_format, "yml", "(Deprecated, use `write_json`) File extension and format for `write_keypoint`: json, xml,"
232  " yaml & yml. Json not available for OpenCV < 3.0, use `write_json` instead.");
233 // Result Saving - Extra Algorithms
-
234 DEFINE_string(write_video_adam, "", "Experimental, not available yet. E.g., `~/Desktop/adamResult.avi`. Flag `camera_fps`"
+
234 DEFINE_string(write_video_adam, "", "Experimental, not available yet. E.g., `~/Desktop/adamResult.avi`. Flag `write_video_fps`"
235  " controls FPS.");
236 DEFINE_string(write_bvh, "", "Experimental, not available yet. E.g., `~/Desktop/mocapResult.bvh`.");
237 // UDP Communication
@@ -349,10 +349,10 @@ $(document).ready(function(){initNavTree('flags_8hpp_source.html','');});
240 #endif // OPENPOSE_FLAGS_DISABLE_POSE
241 
242 #endif // OPENPOSE_FLAGS_HPP
-
DEFINE_double(camera_fps, 30.0,"Frame rate for the webcam (also used when saving video). Set this value to the minimum"" value between the OpenPose displayed speed and the webcam real frame rate.")
DEFINE_bool(disable_multi_thread, false,"It would slightly reduce the frame rate in order to highly reduce the lag. Mainly useful"" for 1) Cases where it is needed a low latency (e.g., webcam in real-time scenarios with"" low-range GPU devices); and 2) Debugging OpenPose when it is crashing to locate the"" error.")
DEFINE_string(camera_resolution,"-1x-1","Set the camera resolution (either `--camera` or `--flir_camera`). `-1x-1` will use the"" default 1280x720 for `--camera`, or the maximum flir camera resolution available for"" `--flir_camera`")
DEFINE_int32(logging_level, 3,"The logging level. Integer in the range [0, 255]. 0 will output any log() message, while"" 255 will not output any. Current OpenPose library messages are in the range 0-4: 1 for"" low priority messages and 4 for important ones.")
+
DEFINE_double(scale_gap, 0.3,"Scale gap between scales. No effect unless scale_number > 1. Initial scale is always 1."" If you want to change the initial scale, you actually want to multiply the"" `net_resolution` by your desired initial scale.")
DEFINE_uint64(frame_first, 0,"Start on desired frame number. Indexes are 0-based, i.e., the first frame has index 0.")
diff --git a/html/functions_func_w.html b/html/functions_func_w.html index 21d20768..218d5ae1 100644 --- a/html/functions_func_w.html +++ b/html/functions_func_w.html @@ -180,7 +180,7 @@ $(document).ready(function(){initNavTree('functions_func_w.html','');}); : op::WDatumProducer< TDatums, TDatumsNoPtr >
  • WebcamReader() -: op::WebcamReader +: op::WebcamReader
  • WFaceDetector() : op::WFaceDetector< TDatums > @@ -349,10 +349,10 @@ $(document).ready(function(){initNavTree('functions_func_w.html','');}); : op::WrapperStructHand
  • WrapperStructInput() -: op::WrapperStructInput +: op::WrapperStructInput
  • WrapperStructOutput() -: op::WrapperStructOutput +: op::WrapperStructOutput
  • WrapperStructPose() : op::WrapperStructPose diff --git a/html/functions_vars.html b/html/functions_vars.html index 03ff8829..3c1ad805 100644 --- a/html/functions_vars.html +++ b/html/functions_vars.html @@ -655,9 +655,6 @@ $(document).ready(function(){initNavTree('functions_vars.html','');});

    - w -

  • - - + + @@ -1623,7 +1623,7 @@ Variables
    `~/Desktop/adamResult.avi`.Flag`camera_fps`""controls FPS." `~/Desktop/adamResult.avi`.Flag`write_video_fps`""controls FPS."   
     
     COMPILE_TEMPLATE_DATUM (WPoseRenderer)
     
    OP_API std::shared_ptr< ProducercreateProducer (const ProducerType producerType=ProducerType::None, const std::string &producerString="", const Point< int > &cameraResolution=Point< int >{-1,-1}, const double webcamFps=30., const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=-1)
     
    OP_API std::shared_ptr< ProducercreateProducer (const ProducerType producerType=ProducerType::None, const std::string &producerString="", const Point< int > &cameraResolution=Point< int >{-1,-1}, const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=-1)
     
     COMPILE_TEMPLATE_DATUM (PriorityQueue)
     
     COMPILE_TEMPLATE_DATUM (Queue)
    -

    Type of producers An enum class in which all the possible type of Producer are included. In order to add a new Producer, include its name in this enum and add a new 'else if' statement inside ProducerFactory::createProducer().

    +

    Type of producers An enum class in which all the possible type of Producer are included. In order to add a new Producer, include its name in this enum and add a new 'else if' statement inside ProducerFactory::createProducer().

    - - +
    Enumerator
    FlirCamera 

    Stereo FLIR (Point-Grey) camera reader. Based on Spinnaker SDK.

    @@ -3314,7 +3314,7 @@ template<typename T > - +
    @@ -3336,12 +3336,6 @@ template<typename T > - - - - - - diff --git a/html/navtree.js b/html/navtree.js index 2212d306..eec40c6c 100644 --- a/html/navtree.js +++ b/html/navtree.js @@ -49,7 +49,7 @@ var NAVTREEINDEX = "gpu_2headers_8hpp.html", "pose_2enum_classes_8hpp.html#af5b3ce2a5d3de87cb31b9b67e96f261fa0c4a19d9254adcb3ca1f0f527ee141fd", "structop_1_1_datum.html#aba90dccffb5a830296231bd430c4766c", -"w_gui3_d_8hpp.html" +"w_gui3_d_8hpp.html#a54b38240e45009f7e6a25d956ac96fe0" ]; var SYNCONMSG = 'click to disable panel synchronisation'; diff --git a/html/navtreeindex10.js b/html/navtreeindex10.js index 23c055bd..12070bbd 100644 --- a/html/navtreeindex10.js +++ b/html/navtreeindex10.js @@ -1,6 +1,5 @@ var NAVTREEINDEX10 = { -"w_gui3_d_8hpp.html":[2,0,0,0,6,8], "w_gui3_d_8hpp.html#a54b38240e45009f7e6a25d956ac96fe0":[2,0,0,0,6,8,1], "w_gui3_d_8hpp_source.html":[2,0,0,0,6,8], "w_gui_8hpp.html":[2,0,0,0,6,7], diff --git a/html/navtreeindex5.js b/html/navtreeindex5.js index 1128d224..6998b515 100644 --- a/html/navtreeindex5.js +++ b/html/navtreeindex5.js @@ -117,10 +117,10 @@ var NAVTREEINDEX5 = "classop_1_1_webcam_reader.html#a9ac58534016e640dce5c5c6b53e5cb6f":[1,0,3,99,7], "classop_1_1_webcam_reader.html#aa03db1223070395d8970038fa3a8203a":[1,0,3,99,4], "classop_1_1_webcam_reader.html#ab4be6381957df794c76b1c9eddd1f676":[1,0,3,99,3], +"classop_1_1_webcam_reader.html#ab6709f433122e783f87db1004e6666f4":[1,0,3,99,0], "classop_1_1_webcam_reader.html#ae66b26829cc2d6e3f02109d4431a7bc2":[1,0,3,99,8], "classop_1_1_webcam_reader.html#aea29bfce4df5493d662ed3a892f364d2":[1,0,3,99,1], "classop_1_1_webcam_reader.html#afbad75f82bf39bfd503bbc8bd881592d":[1,0,3,99,5], -"classop_1_1_webcam_reader.html#afbfa9ebf32ab1c95f0378b49fce0df35":[1,0,3,99,0], "classop_1_1_worker.html":[1,0,3,111], "classop_1_1_worker.html#a3f7c86ab1c4ce15c0f0ef12a1d4647e0":[1,0,3,111,4], "classop_1_1_worker.html#a5008fc4ef4e41366ba0022f5cd79edba":[1,0,3,111,0], diff --git a/html/navtreeindex6.js b/html/navtreeindex6.js index 0ff1e340..b3443d8a 100644 --- a/html/navtreeindex6.js +++ b/html/navtreeindex6.js @@ -96,34 +96,34 @@ var NAVTREEINDEX6 = "flags_8hpp.html#a22572531e5a4896c510639ac57cf522c":[2,0,0,0,15,81], "flags_8hpp.html#a231bec7b2113f31cebb760c849ca2841":[2,0,0,0,15,18], "flags_8hpp.html#a242473077549869f06534e8a9ea1ddd6":[2,0,0,0,15,73], +"flags_8hpp.html#a2473e551c10d8627471382b70fbb838e":[2,0,0,0,15,68], "flags_8hpp.html#a26d1c7340fc87d4593dda754d54145a2":[2,0,0,0,15,70], +"flags_8hpp.html#a26f9e4bae967b528e221c40d21cad543":[2,0,0,0,15,76], "flags_8hpp.html#a284252d3d255ad5e5c35815d720fd67a":[2,0,0,0,15,38], -"flags_8hpp.html#a29f9621cd9361deec9512f8d8b53e6ba":[2,0,0,0,15,20], "flags_8hpp.html#a2aac3e05431b81d298fdbd7f701dcd5e":[2,0,0,0,15,50], -"flags_8hpp.html#a2fe410b6a4ab2577d0f513f5bef78699":[2,0,0,0,15,32], -"flags_8hpp.html#a3051d21eb51cc39eed5f781d8eaed960":[2,0,0,0,15,68], +"flags_8hpp.html#a2fe410b6a4ab2577d0f513f5bef78699":[2,0,0,0,15,31], "flags_8hpp.html#a311e487137e17445e6939abb7cc0cf8f":[2,0,0,0,15,44], "flags_8hpp.html#a3135e093746d3a75b88eb7fb5d0d35e4":[2,0,0,0,15,14], "flags_8hpp.html#a39756aa6d6911435a326e18541db970a":[2,0,0,0,15,54], -"flags_8hpp.html#a3a00f877d52f489ed93fb0db8cb8e4dc":[2,0,0,0,15,23], +"flags_8hpp.html#a3a00f877d52f489ed93fb0db8cb8e4dc":[2,0,0,0,15,22], "flags_8hpp.html#a485d9b07e65fe81454f5f0bdc2d33278":[2,0,0,0,15,40], "flags_8hpp.html#a4c800b6a91b02874d006da33ab8432cd":[2,0,0,0,15,15], "flags_8hpp.html#a4cead735de5b43cfcae5c1139df3be1a":[2,0,0,0,15,49], "flags_8hpp.html#a4da8f1bc0afb58f2a757ab6d90c6042e":[2,0,0,0,15,13], -"flags_8hpp.html#a53eb4c15af968876f31ca0be54d251b3":[2,0,0,0,15,26], +"flags_8hpp.html#a53eb4c15af968876f31ca0be54d251b3":[2,0,0,0,15,25], "flags_8hpp.html#a5aaba99bdb163516d0297d2e09dd0c7d":[2,0,0,0,15,75], "flags_8hpp.html#a5db17b8bc6df4fe40b556af7157dcbf7":[2,0,0,0,15,58], "flags_8hpp.html#a5e350d38962a702d8e0c658fbbb5cc64":[2,0,0,0,15,4], "flags_8hpp.html#a5e8200fc5fd8bc1e80b94b029ea8e18d":[2,0,0,0,15,7], -"flags_8hpp.html#a62bfc56794bb8ceaedd0eb7bc32a0f22":[2,0,0,0,15,25], +"flags_8hpp.html#a62bfc56794bb8ceaedd0eb7bc32a0f22":[2,0,0,0,15,24], "flags_8hpp.html#a63936bd2bc53a453ba74066289ab9d29":[2,0,0,0,15,78], "flags_8hpp.html#a669c6f4820af0275f40808b18147b98c":[2,0,0,0,15,8], "flags_8hpp.html#a66d6d5c07371179c3702dbd1da9d9bd3":[2,0,0,0,15,63], "flags_8hpp.html#a6957bf419a0ca3478948a62a3ce5ecf0":[2,0,0,0,15,67], "flags_8hpp.html#a6a501f229de1ba19801b77fd0565527b":[2,0,0,0,15,3], -"flags_8hpp.html#a6b12d681ace972ae8eede484505c50af":[2,0,0,0,15,29], +"flags_8hpp.html#a6b12d681ace972ae8eede484505c50af":[2,0,0,0,15,28], "flags_8hpp.html#a6c9c8a5843dd8b93e009bf29dc31cde2":[2,0,0,0,15,37], -"flags_8hpp.html#a71043931875d1f5ec677fd69ae96c632":[2,0,0,0,15,28], +"flags_8hpp.html#a71043931875d1f5ec677fd69ae96c632":[2,0,0,0,15,27], "flags_8hpp.html#a72c09e09c94b67f88b53e1a94e7bfe0f":[2,0,0,0,15,77], "flags_8hpp.html#a73ee51843ead02ee6358fe39dcbeffde":[2,0,0,0,15,33], "flags_8hpp.html#a7773e867133822f5601899975dc06adb":[2,0,0,0,15,57], @@ -131,7 +131,7 @@ var NAVTREEINDEX6 = "flags_8hpp.html#a7fc3e871114ac35447499ffda035d51e":[2,0,0,0,15,1], "flags_8hpp.html#a8511765700f652000f2c1c2b1a5df9f9":[2,0,0,0,15,39], "flags_8hpp.html#a85be61a31eaa438a7e9c7d2baf51da47":[2,0,0,0,15,61], -"flags_8hpp.html#a890b2b8df8a57fe4e9baa465c6584ccf":[2,0,0,0,15,30], +"flags_8hpp.html#a890b2b8df8a57fe4e9baa465c6584ccf":[2,0,0,0,15,29], "flags_8hpp.html#a89127a571b2b18ba05912d7b06ffb2ef":[2,0,0,0,15,80], "flags_8hpp.html#a8d76e63210ddd6541cb8b030df0c09cf":[2,0,0,0,15,6], "flags_8hpp.html#a8e9de971b409cfe7fdded7f0d47c502d":[2,0,0,0,15,34], @@ -148,22 +148,22 @@ var NAVTREEINDEX6 = "flags_8hpp.html#aab02d4078b5f7999a582d9c5f4248676":[2,0,0,0,15,56], "flags_8hpp.html#ab30cdb2253e3ea76aa474424e87075eb":[2,0,0,0,15,11], "flags_8hpp.html#ab41c02abe3634f0db65123ecda964a31":[2,0,0,0,15,36], -"flags_8hpp.html#abf5c8a05ae8f86c8e4d8eedbceb84516":[2,0,0,0,15,22], -"flags_8hpp.html#ac17a7af1030d7f5bd69672fec961c083":[2,0,0,0,15,31], +"flags_8hpp.html#aba34d451bc7a9409cdb246e1d945b451":[2,0,0,0,15,32], +"flags_8hpp.html#abf5c8a05ae8f86c8e4d8eedbceb84516":[2,0,0,0,15,21], +"flags_8hpp.html#ac17a7af1030d7f5bd69672fec961c083":[2,0,0,0,15,30], "flags_8hpp.html#ac210b56a3c46ff06143a62b0bb725cc6":[2,0,0,0,15,16], "flags_8hpp.html#ac6c2099e630e05f867ee10b43f35dc65":[2,0,0,0,15,71], "flags_8hpp.html#ac881df85c5be736d05822ad98ac0496f":[2,0,0,0,15,10], "flags_8hpp.html#ad0269da28dc2033e23b8ea84b7e793a2":[2,0,0,0,15,51], "flags_8hpp.html#ad739178d4295e31edd2f1e468bd2e600":[2,0,0,0,15,5], -"flags_8hpp.html#ad7a48143249d608e2ad3a8413eb19c34":[2,0,0,0,15,76], "flags_8hpp.html#ad8c5173beb83c0f9996362b3a3fba820":[2,0,0,0,15,74], -"flags_8hpp.html#ad971ae1068651177e7a78ae68c022792":[2,0,0,0,15,24], +"flags_8hpp.html#ad971ae1068651177e7a78ae68c022792":[2,0,0,0,15,23], "flags_8hpp.html#ada5b7fef5063818fd668359e9e0b0504":[2,0,0,0,15,52], -"flags_8hpp.html#adf35e9261afec1673a42de6197f07f42":[2,0,0,0,15,21], +"flags_8hpp.html#adf35e9261afec1673a42de6197f07f42":[2,0,0,0,15,20], "flags_8hpp.html#aea11a0489c2af278990d3ddff10960fd":[2,0,0,0,15,12], "flags_8hpp.html#af57ca90aafa15b707af299527b0aff6f":[2,0,0,0,15,9], "flags_8hpp.html#af5ee5f61f0d36a03bb8647408f5e236b":[2,0,0,0,15,64], -"flags_8hpp.html#af654373ad667b1683f30e350331ea709":[2,0,0,0,15,27], +"flags_8hpp.html#af654373ad667b1683f30e350331ea709":[2,0,0,0,15,26], "flags_8hpp.html#afaf97bbf6a49576782d25147bc865bed":[2,0,0,0,15,65], "flags_8hpp.html#afdfef14901f7b5e324d6983845f5ab50":[2,0,0,0,15,47], "flags_8hpp.html#aff61246512375ff5941dc4110e127ca3":[2,0,0,0,15,59], diff --git a/html/navtreeindex7.js b/html/navtreeindex7.js index 3af982ee..293c33e7 100644 --- a/html/navtreeindex7.js +++ b/html/navtreeindex7.js @@ -136,14 +136,14 @@ var NAVTREEINDEX7 = "maximum_caffe_8hpp_source.html":[2,0,0,0,8,4], "namespaceboost.html":[1,0,0], "namespaceboost.html":[0,0,0], -"namespacecaffe.html":[1,0,1], "namespacecaffe.html":[0,0,1], +"namespacecaffe.html":[1,0,1], "namespacecl.html":[1,0,2], "namespacecl.html":[0,0,2], "namespacecl_1_1compatibility.html":[1,0,2,0], "namespacecl_1_1compatibility.html":[0,0,2,0], -"namespacecl_1_1detail.html":[0,0,2,1], "namespacecl_1_1detail.html":[1,0,2,1], +"namespacecl_1_1detail.html":[0,0,2,1], "namespacemembers.html":[0,1,0], "namespacemembers.html":[0,1,0,0], "namespacemembers_b.html":[0,1,0,1], @@ -195,8 +195,8 @@ var NAVTREEINDEX7 = "namespacemembers_x.html":[0,1,0,23], "namespacemembers_y.html":[0,1,0,24], "namespacemembers_z.html":[0,1,0,25], -"namespaceop.html":[0,0,3], "namespaceop.html":[1,0,3], +"namespaceop.html":[0,0,3], "namespaceop_1_1_configure_error.html":[1,0,3,0], "namespaceop_1_1_configure_error.html":[0,0,3,0], "namespaceop_1_1_configure_log.html":[1,0,3,1], diff --git a/html/navtreeindex8.js b/html/navtreeindex8.js index 8d7503fd..f375f2b5 100644 --- a/html/navtreeindex8.js +++ b/html/navtreeindex8.js @@ -109,7 +109,7 @@ var NAVTREEINDEX8 = "producer_2headers_8hpp.html":[2,0,0,0,10,3], "producer_2headers_8hpp_source.html":[2,0,0,0,10,3], "producer_8hpp.html":[2,0,0,0,10,6], -"producer_8hpp.html#aff1530aa4f78f3c55b7df9b452ceee94":[2,0,0,0,10,6,1], +"producer_8hpp.html#a70c5ea34fa5f283a820c6090c674cbc7":[2,0,0,0,10,6,1], "producer_8hpp_source.html":[2,0,0,0,10,6], "profiler_8hpp.html":[2,0,0,0,13,10], "profiler_8hpp_source.html":[2,0,0,0,13,10], diff --git a/html/navtreeindex9.js b/html/navtreeindex9.js index 83406581..d3a1e3d3 100644 --- a/html/navtreeindex9.js +++ b/html/navtreeindex9.js @@ -106,8 +106,7 @@ var NAVTREEINDEX9 = "structop_1_1_wrapper_struct_input.html":[1,0,3,129], "structop_1_1_wrapper_struct_input.html#a03e5628a93671e1d771b3080d3c4f1e7":[1,0,3,129,10], "structop_1_1_wrapper_struct_input.html#a2eeea9ee711a1dcbec99c3dc871fbc47":[1,0,3,129,12], -"structop_1_1_wrapper_struct_input.html#a49970fa2a3e14394ac49c1f0679c72f5":[1,0,3,129,14], -"structop_1_1_wrapper_struct_input.html#a529d945c83bb69ac1db7b8db371e6622":[1,0,3,129,0], +"structop_1_1_wrapper_struct_input.html#a55839a660d5259c5a4adb0639bdf156d":[1,0,3,129,0], "structop_1_1_wrapper_struct_input.html#a5cffb282052bdd812217e54f0b2ec7d5":[1,0,3,129,5], "structop_1_1_wrapper_struct_input.html#a5ee9722814fe2b5a695511cabd12b613":[1,0,3,129,4], "structop_1_1_wrapper_struct_input.html#a7c80f6a3687696ba30d3ce0902ac162f":[1,0,3,129,7], @@ -122,7 +121,6 @@ var NAVTREEINDEX9 = "structop_1_1_wrapper_struct_output.html":[1,0,3,130], "structop_1_1_wrapper_struct_output.html#a0119bb7429483928c587ffaf607919de":[1,0,3,130,7], "structop_1_1_wrapper_struct_output.html#a34d5796e02b8afaaaef99fc26e7f3056":[1,0,3,130,9], -"structop_1_1_wrapper_struct_output.html#a429cbf2dbb9464ad6c5937033211c928":[1,0,3,130,0], "structop_1_1_wrapper_struct_output.html#a5f56c15d410645442b5ac21c316b9c85":[1,0,3,130,10], "structop_1_1_wrapper_struct_output.html#a6efbd77da8ebcea3abc4109bb2f39c0b":[1,0,3,130,6], "structop_1_1_wrapper_struct_output.html#a73d6a5687ab8abac22f5cd29690b6277":[1,0,3,130,15], @@ -138,6 +136,7 @@ var NAVTREEINDEX9 = "structop_1_1_wrapper_struct_output.html#add74785fc0cb1fc7d2c6b5f88b622d53":[1,0,3,130,4], "structop_1_1_wrapper_struct_output.html#aec3a7ec85be0779930427ba3e806ea2c":[1,0,3,130,2], "structop_1_1_wrapper_struct_output.html#aec57f5b4f6920cd43c2f6e55a21c769b":[1,0,3,130,3], +"structop_1_1_wrapper_struct_output.html#af12d5e43eef90a3c0f8cc0b0d805b313":[1,0,3,130,0], "structop_1_1_wrapper_struct_pose.html":[1,0,3,131], "structop_1_1_wrapper_struct_pose.html#a02c4ab6b56e4da4b3ed0da4eae8ac0fc":[1,0,3,131,16], "structop_1_1_wrapper_struct_pose.html#a17b6f8cf237c7b0399c65d432188165a":[1,0,3,131,0], @@ -249,5 +248,6 @@ var NAVTREEINDEX9 = "w_face_renderer_8hpp_source.html":[2,0,0,0,3,13], "w_face_saver_8hpp.html":[2,0,0,0,4,15], "w_face_saver_8hpp.html#a57c4f3ada0db4882a4106d4dedf08012":[2,0,0,0,4,15,1], -"w_face_saver_8hpp_source.html":[2,0,0,0,4,15] +"w_face_saver_8hpp_source.html":[2,0,0,0,4,15], +"w_gui3_d_8hpp.html":[2,0,0,0,6,8] }; diff --git a/html/producer_8hpp.html b/html/producer_8hpp.html index fca27cf5..517e586f 100644 --- a/html/producer_8hpp.html +++ b/html/producer_8hpp.html @@ -130,8 +130,8 @@ Namespaces
    const Point< int > &  cameraResolution = Point< int >{-1,-1},
    const double webcamFps = 30.,
    - - + +

    Functions

    OP_API std::shared_ptr< Producer > op::createProducer (const ProducerType producerType=ProducerType::None, const std::string &producerString="", const Point< int > &cameraResolution=Point< int >{-1,-1}, const double webcamFps=30., const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=-1)
     
    OP_API std::shared_ptr< Producer > op::createProducer (const ProducerType producerType=ProducerType::None, const std::string &producerString="", const Point< int > &cameraResolution=Point< int >{-1,-1}, const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=-1)
     
    diff --git a/html/producer_8hpp.js b/html/producer_8hpp.js index 740095e1..7f9f0de3 100644 --- a/html/producer_8hpp.js +++ b/html/producer_8hpp.js @@ -1,5 +1,5 @@ var producer_8hpp = [ [ "Producer", "classop_1_1_producer.html", "classop_1_1_producer" ], - [ "createProducer", "producer_8hpp.html#aff1530aa4f78f3c55b7df9b452ceee94", null ] + [ "createProducer", "producer_8hpp.html#a70c5ea34fa5f283a820c6090c674cbc7", null ] ]; \ No newline at end of file diff --git a/html/producer_8hpp_source.html b/html/producer_8hpp_source.html index 8618d318..b2a8da82 100644 --- a/html/producer_8hpp_source.html +++ b/html/producer_8hpp_source.html @@ -183,9 +183,9 @@ $(document).ready(function(){initNavTree('producer_8hpp_source.html','');});
    180  };
    181 
    -
    185  OP_API std::shared_ptr<Producer> createProducer(
    +
    185  OP_API std::shared_ptr<Producer> createProducer(
    186  const ProducerType producerType = ProducerType::None, const std::string& producerString = "",
    -
    187  const Point<int>& cameraResolution = Point<int>{-1,-1}, const double webcamFps = 30.,
    +
    187  const Point<int>& cameraResolution = Point<int>{-1,-1},
    188  const std::string& cameraParameterPath = "models/cameraParameters/", const bool undistortImage = true,
    189  const unsigned int imageDirectoryStereo = -1);
    190 }
    @@ -193,11 +193,11 @@ $(document).ready(function(){initNavTree('producer_8hpp_source.html','');});
    192 #endif // OPENPOSE_PRODUCER_PRODUCER_HPP
    #define DELETE_COPY(className)
    Definition: macros.hpp:34
    -
    OP_API std::shared_ptr< Producer > createProducer(const ProducerType producerType=ProducerType::None, const std::string &producerString="", const Point< int > &cameraResolution=Point< int >{-1,-1}, const double webcamFps=30., const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=-1)
    ProducerFpsMode
    Definition: enumClasses.hpp:6
    ProducerProperty
    Definition: enumClasses.hpp:14
    Definition: producer.hpp:15
    +
    OP_API std::shared_ptr< Producer > createProducer(const ProducerType producerType=ProducerType::None, const std::string &producerString="", const Point< int > &cameraResolution=Point< int >{-1,-1}, const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=-1)
    ProducerType getType()
    Definition: producer.hpp:79
    ProducerType
    Definition: enumClasses.hpp:28
    #define OP_API
    Definition: macros.hpp:19
    diff --git a/html/search/all_16.js b/html/search/all_16.js index 98920ae7..c5a5546b 100644 --- a/html/search/all_16.js +++ b/html/search/all_16.js @@ -19,9 +19,8 @@ var searchData= ['wdatumproducer',['WDatumProducer',['../classop_1_1_w_datum_producer.html#aaba921d1cf641dc44ab509c0e460c5f1',1,'op::WDatumProducer']]], ['wdatumproducer_2ehpp',['wDatumProducer.hpp',['../w_datum_producer_8hpp.html',1,'']]], ['webcam',['Webcam',['../namespaceop.html#a54b73745852c270cfd891eed0f6f2332ae2faa2a74b6a4134d0b3e84c7c0e2a01',1,'op']]], - ['webcamfps',['webcamFps',['../structop_1_1_wrapper_struct_input.html#a49970fa2a3e14394ac49c1f0679c72f5',1,'op::WrapperStructInput']]], ['webcamreader',['WebcamReader',['../classop_1_1_webcam_reader.html',1,'op']]], - ['webcamreader',['WebcamReader',['../classop_1_1_webcam_reader.html#afbfa9ebf32ab1c95f0378b49fce0df35',1,'op::WebcamReader']]], + ['webcamreader',['WebcamReader',['../classop_1_1_webcam_reader.html#ab6709f433122e783f87db1004e6666f4',1,'op::WebcamReader']]], ['webcamreader_2ehpp',['webcamReader.hpp',['../webcam_reader_8hpp.html',1,'']]], ['wfacedetector',['WFaceDetector',['../classop_1_1_w_face_detector.html',1,'op']]], ['wfacedetector',['WFaceDetector',['../classop_1_1_w_face_detector.html#a77355426bc59b212a8eb1730ff6289f3',1,'op::WFaceDetector']]], @@ -76,8 +75,8 @@ var searchData= ['widgenerator',['WIdGenerator',['../classop_1_1_w_id_generator.html',1,'op']]], ['widgenerator_2ehpp',['wIdGenerator.hpp',['../w_id_generator_8hpp.html',1,'']]], ['width',['width',['../structop_1_1_rectangle.html#a0d0ae826039b0961fae8723708809cdf',1,'op::Rectangle']]], - ['wimagesaver',['WImageSaver',['../classop_1_1_w_image_saver.html#a11add012ee88b64a4f36d3f63cb65ee0',1,'op::WImageSaver']]], ['wimagesaver',['WImageSaver',['../classop_1_1_w_image_saver.html',1,'op']]], + ['wimagesaver',['WImageSaver',['../classop_1_1_w_image_saver.html#a11add012ee88b64a4f36d3f63cb65ee0',1,'op::WImageSaver']]], ['wimagesaver_2ehpp',['wImageSaver.hpp',['../w_image_saver_8hpp.html',1,'']]], ['windowed',['Windowed',['../namespaceop.html#a6c22a72ce93c64e7582cb670492a50bfab13311ab51c4c34757f67f26580018dd',1,'op']]], ['wjointangleestimation_2ehpp',['wJointAngleEstimation.hpp',['../w_joint_angle_estimation_8hpp.html',1,'']]], @@ -126,11 +125,11 @@ var searchData= ['wqueueassembler',['WQueueAssembler',['../classop_1_1_w_queue_assembler.html',1,'op']]], ['wqueueassembler',['WQueueAssembler',['../classop_1_1_w_queue_assembler.html#a8d73df6a562bd797e16d2bb3ced83b6d',1,'op::WQueueAssembler']]], ['wqueueassembler_2ehpp',['wQueueAssembler.hpp',['../w_queue_assembler_8hpp.html',1,'']]], - ['wqueueorderer',['WQueueOrderer',['../classop_1_1_w_queue_orderer.html',1,'op']]], ['wqueueorderer',['WQueueOrderer',['../classop_1_1_w_queue_orderer.html#a3303add5fa8cc36593d3d859ffdd8ae0',1,'op::WQueueOrderer']]], + ['wqueueorderer',['WQueueOrderer',['../classop_1_1_w_queue_orderer.html',1,'op']]], ['wqueueorderer_2ehpp',['wQueueOrderer.hpp',['../w_queue_orderer_8hpp.html',1,'']]], - ['wrapper',['Wrapper',['../classcl_1_1detail_1_1_wrapper.html#aa1b916a75114fe3217018378d5f1eb71',1,'cl::detail::Wrapper::Wrapper()'],['../classcl_1_1detail_1_1_wrapper.html#a98dce667e0f400f2ba15a8a8d65fdea0',1,'cl::detail::Wrapper::Wrapper(const cl_type &obj, bool retainObject)'],['../classcl_1_1detail_1_1_wrapper.html#af91bafdf8593c34e0d0722cdd93010be',1,'cl::detail::Wrapper::Wrapper(const Wrapper< cl_type > &rhs)'],['../classcl_1_1detail_1_1_wrapper.html#a115618e2baf10ec5c09513394d985ea6',1,'cl::detail::Wrapper::Wrapper(Wrapper< cl_type > &&rhs) CL_HPP_NOEXCEPT_'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a6881f47b159f53e2efefc3325127bdc5',1,'cl::detail::Wrapper< cl_device_id >::Wrapper()'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a69a1b6a912ec468216ddfec1f5b6598e',1,'cl::detail::Wrapper< cl_device_id >::Wrapper(const cl_type &obj, bool retainObject)'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a0abf5113a5123b8de94685ddfa214bd0',1,'cl::detail::Wrapper< cl_device_id >::Wrapper(const Wrapper< cl_type > &rhs)'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a6a4506b8f3920fb2487b1a5448a6f10c',1,'cl::detail::Wrapper< cl_device_id >::Wrapper(Wrapper< cl_type > &&rhs) CL_HPP_NOEXCEPT_'],['../namespaceop.html#a3434981351c0d4d04eac3b29dfc22fbd',1,'op::Wrapper()']]], ['wrapper',['Wrapper',['../classcl_1_1detail_1_1_wrapper.html',1,'cl::detail']]], + ['wrapper',['Wrapper',['../classcl_1_1detail_1_1_wrapper.html#aa1b916a75114fe3217018378d5f1eb71',1,'cl::detail::Wrapper::Wrapper()'],['../classcl_1_1detail_1_1_wrapper.html#a98dce667e0f400f2ba15a8a8d65fdea0',1,'cl::detail::Wrapper::Wrapper(const cl_type &obj, bool retainObject)'],['../classcl_1_1detail_1_1_wrapper.html#af91bafdf8593c34e0d0722cdd93010be',1,'cl::detail::Wrapper::Wrapper(const Wrapper< cl_type > &rhs)'],['../classcl_1_1detail_1_1_wrapper.html#a115618e2baf10ec5c09513394d985ea6',1,'cl::detail::Wrapper::Wrapper(Wrapper< cl_type > &&rhs) CL_HPP_NOEXCEPT_'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a6881f47b159f53e2efefc3325127bdc5',1,'cl::detail::Wrapper< cl_device_id >::Wrapper()'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a69a1b6a912ec468216ddfec1f5b6598e',1,'cl::detail::Wrapper< cl_device_id >::Wrapper(const cl_type &obj, bool retainObject)'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a0abf5113a5123b8de94685ddfa214bd0',1,'cl::detail::Wrapper< cl_device_id >::Wrapper(const Wrapper< cl_type > &rhs)'],['../classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html#a6a4506b8f3920fb2487b1a5448a6f10c',1,'cl::detail::Wrapper< cl_device_id >::Wrapper(Wrapper< cl_type > &&rhs) CL_HPP_NOEXCEPT_'],['../namespaceop.html#a3434981351c0d4d04eac3b29dfc22fbd',1,'op::Wrapper()']]], ['wrapper_2ehpp',['wrapper.hpp',['../wrapper_8hpp.html',1,'']]], ['wrapper_3c_20cl_5fcommand_5fqueue_20_3e',['Wrapper< cl_command_queue >',['../classcl_1_1detail_1_1_wrapper.html',1,'cl::detail']]], ['wrapper_3c_20cl_5fcontext_20_3e',['Wrapper< cl_context >',['../classcl_1_1detail_1_1_wrapper.html',1,'cl::detail']]], @@ -156,13 +155,13 @@ var searchData= ['wrapperstructhand',['WrapperStructHand',['../structop_1_1_wrapper_struct_hand.html',1,'op']]], ['wrapperstructhand_2ehpp',['wrapperStructHand.hpp',['../wrapper_struct_hand_8hpp.html',1,'']]], ['wrapperstructinput',['WrapperStructInput',['../structop_1_1_wrapper_struct_input.html',1,'op']]], - ['wrapperstructinput',['WrapperStructInput',['../structop_1_1_wrapper_struct_input.html#a529d945c83bb69ac1db7b8db371e6622',1,'op::WrapperStructInput']]], + ['wrapperstructinput',['WrapperStructInput',['../structop_1_1_wrapper_struct_input.html#a55839a660d5259c5a4adb0639bdf156d',1,'op::WrapperStructInput']]], ['wrapperstructinput_2ehpp',['wrapperStructInput.hpp',['../wrapper_struct_input_8hpp.html',1,'']]], ['wrapperstructoutput',['WrapperStructOutput',['../structop_1_1_wrapper_struct_output.html',1,'op']]], - ['wrapperstructoutput',['WrapperStructOutput',['../structop_1_1_wrapper_struct_output.html#a429cbf2dbb9464ad6c5937033211c928',1,'op::WrapperStructOutput']]], + ['wrapperstructoutput',['WrapperStructOutput',['../structop_1_1_wrapper_struct_output.html#af12d5e43eef90a3c0f8cc0b0d805b313',1,'op::WrapperStructOutput']]], ['wrapperstructoutput_2ehpp',['wrapperStructOutput.hpp',['../wrapper_struct_output_8hpp.html',1,'']]], - ['wrapperstructpose',['WrapperStructPose',['../structop_1_1_wrapper_struct_pose.html',1,'op']]], ['wrapperstructpose',['WrapperStructPose',['../structop_1_1_wrapper_struct_pose.html#a17b6f8cf237c7b0399c65d432188165a',1,'op::WrapperStructPose']]], + ['wrapperstructpose',['WrapperStructPose',['../structop_1_1_wrapper_struct_pose.html',1,'op']]], ['wrapperstructpose_2ehpp',['wrapperStructPose.hpp',['../wrapper_struct_pose_8hpp.html',1,'']]], ['wrappert',['WrapperT',['../classop_1_1_wrapper_t.html',1,'op']]], ['wrappert',['WrapperT',['../classop_1_1_wrapper_t.html#af1a56f0542a2cbcc11d6b185adeb5626',1,'op::WrapperT']]], @@ -182,16 +181,16 @@ var searchData= ['writevideo',['writeVideo',['../structop_1_1_wrapper_struct_output.html#a73d6a5687ab8abac22f5cd29690b6277',1,'op::WrapperStructOutput']]], ['writevideoadam',['writeVideoAdam',['../structop_1_1_wrapper_struct_output.html#a94538578a465c78788760cadb8ea86f6',1,'op::WrapperStructOutput']]], ['writevideofps',['writeVideoFps',['../structop_1_1_wrapper_struct_output.html#ad595edffced2bfd80c3bee183f32f505',1,'op::WrapperStructOutput']]], - ['wscaleandsizeextractor',['WScaleAndSizeExtractor',['../classop_1_1_w_scale_and_size_extractor.html',1,'op']]], ['wscaleandsizeextractor',['WScaleAndSizeExtractor',['../classop_1_1_w_scale_and_size_extractor.html#a8e6ef291bd809987f06fbb1cc2173b0f',1,'op::WScaleAndSizeExtractor']]], + ['wscaleandsizeextractor',['WScaleAndSizeExtractor',['../classop_1_1_w_scale_and_size_extractor.html',1,'op']]], ['wscaleandsizeextractor_2ehpp',['wScaleAndSizeExtractor.hpp',['../w_scale_and_size_extractor_8hpp.html',1,'']]], - ['wudpsender',['WUdpSender',['../classop_1_1_w_udp_sender.html#a22a5ec90fe83ed654bd0aef112fac98b',1,'op::WUdpSender']]], ['wudpsender',['WUdpSender',['../classop_1_1_w_udp_sender.html',1,'op']]], + ['wudpsender',['WUdpSender',['../classop_1_1_w_udp_sender.html#a22a5ec90fe83ed654bd0aef112fac98b',1,'op::WUdpSender']]], ['wudpsender_2ehpp',['wUdpSender.hpp',['../w_udp_sender_8hpp.html',1,'']]], - ['wverboseprinter',['WVerbosePrinter',['../classop_1_1_w_verbose_printer.html#a6ece5acbf5f8a7a3e900c5029a56271d',1,'op::WVerbosePrinter']]], ['wverboseprinter',['WVerbosePrinter',['../classop_1_1_w_verbose_printer.html',1,'op']]], + ['wverboseprinter',['WVerbosePrinter',['../classop_1_1_w_verbose_printer.html#a6ece5acbf5f8a7a3e900c5029a56271d',1,'op::WVerbosePrinter']]], ['wverboseprinter_2ehpp',['wVerbosePrinter.hpp',['../w_verbose_printer_8hpp.html',1,'']]], - ['wvideosaver',['WVideoSaver',['../classop_1_1_w_video_saver.html#a04dc4e6f039d047a0da6f94283c145d9',1,'op::WVideoSaver']]], ['wvideosaver',['WVideoSaver',['../classop_1_1_w_video_saver.html',1,'op']]], + ['wvideosaver',['WVideoSaver',['../classop_1_1_w_video_saver.html#a04dc4e6f039d047a0da6f94283c145d9',1,'op::WVideoSaver']]], ['wvideosaver_2ehpp',['wVideoSaver.hpp',['../w_video_saver_8hpp.html',1,'']]] ]; diff --git a/html/search/all_2.js b/html/search/all_2.js index cae1d412..c82e6134 100644 --- a/html/search/all_2.js +++ b/html/search/all_2.js @@ -94,7 +94,7 @@ var searchData= ['createarray',['createArray',['../classop_1_1_cv_mat_to_op_input.html#acf0c43174fe8e3b1c71d76aca861a6ab',1,'op::CvMatToOpInput::createArray()'],['../classop_1_1_cv_mat_to_op_output.html#a003515873bf34525e2a6d313d8619ff3',1,'op::CvMatToOpOutput::createArray()']]], ['createkernels',['createKernels',['../classcl_1_1_program.html#a8251f8a862bdfd82caf10a949b2bd884',1,'cl::Program']]], ['createpeoplevector',['createPeopleVector',['../namespaceop.html#ae9cb91cf03ed561a31b9f4c950926731',1,'op']]], - ['createproducer',['createProducer',['../namespaceop.html#aff1530aa4f78f3c55b7df9b452ceee94',1,'op']]], + ['createproducer',['createProducer',['../namespaceop.html#a70c5ea34fa5f283a820c6090c674cbc7',1,'op']]], ['createsubbuffer',['createSubBuffer',['../classcl_1_1_buffer.html#ab73f1e0ab2224f3d515820dd6b0c1d73',1,'cl::Buffer']]], ['createsubdevices',['createSubDevices',['../classcl_1_1_device.html#ab60bfd190bf8f82cb8f0adb0a869a2f2',1,'cl::Device']]], ['cuda',['Cuda',['../namespaceop.html#adbb34b5c8f2b6f0c051f831f18582e7fa8b95dcff7397d0693c03e394af5552aa',1,'op']]], diff --git a/html/search/all_3.js b/html/search/all_3.js index e03492e5..bd853d2d 100644 --- a/html/search/all_3.js +++ b/html/search/all_3.js @@ -14,9 +14,9 @@ var searchData= ['default_5fx',['DEFAULT_X',['../classop_1_1_profiler.html#a13de5fe55b2599c0626d5071d3851dec',1,'op::Profiler']]], ['defaultparttorender',['defaultPartToRender',['../structop_1_1_wrapper_struct_pose.html#ab6810e97aa62a728aa09dbbe6b9b6c06',1,'op::WrapperStructPose']]], ['define_5fbool',['DEFINE_bool',['../flags_8hpp.html#a035ba7d578f36103d096569f1984ab61',1,'DEFINE_bool(disable_multi_thread, false,"It would slightly reduce the frame rate in order to highly reduce the lag. Mainly useful"" for 1) Cases where it is needed a low latency (e.g., webcam in real-time scenarios with"" low-range GPU devices); and 2) Debugging OpenPose when it is crashing to locate the"" error."): flags.hpp'],['../flags_8hpp.html#a7fc3e871114ac35447499ffda035d51e',1,'DEFINE_bool(flir_camera, false,"Whether to use FLIR (Point-Grey) stereo camera."): flags.hpp'],['../flags_8hpp.html#a9d45877ef21b9042f1b307d23d404e40',1,'DEFINE_bool(frame_flip, false,"Flip/mirror each frame (e.g., for real time webcam demonstrations)."): flags.hpp'],['../flags_8hpp.html#a6a501f229de1ba19801b77fd0565527b',1,'DEFINE_bool(frames_repeat, false,"Repeat frames when finished."): flags.hpp'],['../flags_8hpp.html#a5e350d38962a702d8e0c658fbbb5cc64',1,'DEFINE_bool(process_real_time, false,"Enable to keep the original source frame rate (e.g., for video). If the processing time is"" too long, it will skip frames. If it is too fast, it will slow it down."): flags.hpp'],['../flags_8hpp.html#ad739178d4295e31edd2f1e468bd2e600',1,'DEFINE_bool(frame_keep_distortion, false,"If false (default), it will undistortionate the image based on the"" `camera_parameter_folder` camera parameters; if true, it will not undistortionate, i.e.,"" it will leave it as it is."): flags.hpp'],['../flags_8hpp.html#a8d76e63210ddd6541cb8b030df0c09cf',1,'DEFINE_bool(maximize_positives, false,"It reduces the thresholds to accept a person candidate. It highly increases both false and"" true positives. I.e., it maximizes average recall but could harm average precision."): flags.hpp'],['../flags_8hpp.html#a5e8200fc5fd8bc1e80b94b029ea8e18d',1,'DEFINE_bool(body_disable, false,"Disable body keypoint detection. Option only possible for faster (but less accurate) face"" keypoint detection."): flags.hpp'],['../flags_8hpp.html#a669c6f4820af0275f40808b18147b98c',1,'DEFINE_bool(heatmaps_add_parts, false,"If true, it will fill op::Datum::poseHeatMaps array with the body part heatmaps, and"" analogously face & hand heatmaps to op::Datum::faceHeatMaps & op::Datum::handHeatMaps."" If more than one `add_heatmaps_X` flag is enabled, it will place then in sequential"" memory order: body parts + bkg + PAFs. It will follow the order on"" POSE_BODY_PART_MAPPING in `src/openpose/pose/poseParameters.cpp`. Program speed will"" considerably decrease. Not required for OpenPose, enable it only if you intend to"" explicitly use this information later."): flags.hpp'],['../flags_8hpp.html#af57ca90aafa15b707af299527b0aff6f',1,'DEFINE_bool(heatmaps_add_bkg, false,"Same functionality as `add_heatmaps_parts`, but adding the heatmap corresponding to"" background."): flags.hpp'],['../flags_8hpp.html#ac881df85c5be736d05822ad98ac0496f',1,'DEFINE_bool(heatmaps_add_PAFs, false,"Same functionality as `add_heatmaps_parts`, but adding the PAFs."): flags.hpp'],['../flags_8hpp.html#ab30cdb2253e3ea76aa474424e87075eb',1,'DEFINE_bool(part_candidates, false,"Also enable `write_json` in order to save this information. If true, it will fill the"" op::Datum::poseCandidates array with the body part candidates. Candidates refer to all"" the detected body parts, before being assembled into people. Note that the number of"" candidates is equal or higher than the number of final body parts (i.e., after being"" assembled into people). The empty body parts are filled with 0s. Program speed will"" slightly decrease. Not required for OpenPose, enable it only if you intend to explicitly"" use this information."): flags.hpp'],['../flags_8hpp.html#aea11a0489c2af278990d3ddff10960fd',1,'DEFINE_bool(face, false,"Enables face keypoint detection. It will share some parameters from the body pose, e.g."" `model_folder`. Note that this will considerable slow down the performance and increse"" the required GPU memory. In addition, the greater number of people on the image, the"" slower OpenPose will be."): flags.hpp'],['../flags_8hpp.html#a4da8f1bc0afb58f2a757ab6d90c6042e',1,'DEFINE_bool(hand, false,"Enables hand keypoint detection. It will share some parameters from the body pose, e.g."" `model_folder`. Analogously to `--face`, it will also slow down the performance, increase"" the required GPU memory and its speed depends on the number of people."): flags.hpp'],['../flags_8hpp.html#a3135e093746d3a75b88eb7fb5d0d35e4',1,'DEFINE_bool(hand_tracking, false,"Adding hand tracking might improve hand keypoints detection for webcam (if the frame rate"" is high enough, i.e., >7 FPS per GPU) and video. This is not person ID tracking, it"" simply looks for hands in positions at which hands were located in previous frames, but"" it does not guarantee the same person ID among frames."): flags.hpp'],['../flags_8hpp.html#a4c800b6a91b02874d006da33ab8432cd',1,'DEFINE_bool(3d, false,"Running OpenPose 3-D reconstruction demo: 1) Reading from a stereo camera system."" 2) Performing 3-D reconstruction from the multiple views. 3) Displaying 3-D reconstruction"" results. Note that it will only display 1 person. If multiple people is present, it will"" fail."): flags.hpp'],['../flags_8hpp.html#ac210b56a3c46ff06143a62b0bb725cc6',1,'DEFINE_bool(identification, false,"Experimental, not available yet. Whether to enable people identification across frames."): flags.hpp'],['../flags_8hpp.html#a1a9ffc302eac69c8ba024da3edf01a5f',1,'DEFINE_bool(disable_blending, false,"If enabled, it will render the results (keypoint skeletons or heatmaps) on a black"" background, instead of being rendered into the original image. Related: `part_to_show`,"" `alpha_pose`, and `alpha_pose`."): flags.hpp'],['../flags_8hpp.html#a231bec7b2113f31cebb760c849ca2841',1,'DEFINE_bool(fullscreen, false,"Run in full-screen mode (press f during runtime to toggle)."): flags.hpp'],['../flags_8hpp.html#a0ee4f86d572ef52ec26dcbb37efb5e65',1,'DEFINE_bool(no_gui_verbose, false,"Do not write text on output images on GUI (e.g., number of current frame and people). It"" does not affect the pose rendering."): flags.hpp']]], - ['define_5fdouble',['DEFINE_double',['../flags_8hpp.html#a29f9621cd9361deec9512f8d8b53e6ba',1,'DEFINE_double(camera_fps, 30.0,"Frame rate for the webcam (also used when saving video). Set this value to the minimum"" value between the OpenPose displayed speed and the webcam real frame rate."): flags.hpp'],['../flags_8hpp.html#adf35e9261afec1673a42de6197f07f42',1,'DEFINE_double(scale_gap, 0.3,"Scale gap between scales. No effect unless scale_number > 1. Initial scale is always 1."" If you want to change the initial scale, you actually want to multiply the"" `net_resolution` by your desired initial scale."): flags.hpp'],['../flags_8hpp.html#abf5c8a05ae8f86c8e4d8eedbceb84516',1,'DEFINE_double(hand_scale_range, 0.4,"Analogous purpose than `scale_gap` but applied to the hand keypoint detector. Total range"" between smallest and biggest scale. The scales will be centered in ratio 1. E.g., if"" scaleRange = 0.4 and scalesNumber = 2, then there will be 2 scales, 0.8 and 1.2."): flags.hpp'],['../flags_8hpp.html#a3a00f877d52f489ed93fb0db8cb8e4dc',1,'DEFINE_double(render_threshold, 0.05,"Only estimated keypoints whose score confidences are higher than this threshold will be"" rendered. Generally, a high threshold (> 0.5) will only render very clear body parts;"" while small thresholds (~0.1) will also output guessed and occluded keypoints, but also"" more false positives (i.e., wrong detections)."): flags.hpp'],['../flags_8hpp.html#ad971ae1068651177e7a78ae68c022792',1,'DEFINE_double(alpha_pose, 0.6,"Blending factor (range 0-1) for the body part rendering. 1 will show it completely, 0 will"" hide it. Only valid for GPU rendering."): flags.hpp'],['../flags_8hpp.html#a62bfc56794bb8ceaedd0eb7bc32a0f22',1,'DEFINE_double(alpha_heatmap, 0.7,"Blending factor (range 0-1) between heatmap and original frame. 1 will only show the"" heatmap, 0 will only show the frame. Only valid for GPU rendering."): flags.hpp'],['../flags_8hpp.html#a53eb4c15af968876f31ca0be54d251b3',1,'DEFINE_double(face_render_threshold, 0.4,"Analogous to `render_threshold`, but applied to the face keypoints."): flags.hpp'],['../flags_8hpp.html#af654373ad667b1683f30e350331ea709',1,'DEFINE_double(face_alpha_pose, 0.6,"Analogous to `alpha_pose` but applied to face."): flags.hpp'],['../flags_8hpp.html#a71043931875d1f5ec677fd69ae96c632',1,'DEFINE_double(face_alpha_heatmap, 0.7,"Analogous to `alpha_heatmap` but applied to face."): flags.hpp'],['../flags_8hpp.html#a6b12d681ace972ae8eede484505c50af',1,'DEFINE_double(hand_render_threshold, 0.2,"Analogous to `render_threshold`, but applied to the hand keypoints."): flags.hpp'],['../flags_8hpp.html#a890b2b8df8a57fe4e9baa465c6584ccf',1,'DEFINE_double(hand_alpha_pose, 0.6,"Analogous to `alpha_pose` but applied to hand."): flags.hpp'],['../flags_8hpp.html#ac17a7af1030d7f5bd69672fec961c083',1,'DEFINE_double(hand_alpha_heatmap, 0.7,"Analogous to `alpha_heatmap` but applied to hand."): flags.hpp'],['../flags_8hpp.html#a2fe410b6a4ab2577d0f513f5bef78699',1,'DEFINE_double(cli_verbose,-1.f,"If -1, it will be disabled (default). If it is a positive integer number, it will print on"" the command line every `verbose` frames. If number in the range (0,1), it will print the"" progress every `verbose` times the total of frames."): flags.hpp']]], + ['define_5fdouble',['DEFINE_double',['../flags_8hpp.html#adf35e9261afec1673a42de6197f07f42',1,'DEFINE_double(scale_gap, 0.3,"Scale gap between scales. No effect unless scale_number > 1. Initial scale is always 1."" If you want to change the initial scale, you actually want to multiply the"" `net_resolution` by your desired initial scale."): flags.hpp'],['../flags_8hpp.html#abf5c8a05ae8f86c8e4d8eedbceb84516',1,'DEFINE_double(hand_scale_range, 0.4,"Analogous purpose than `scale_gap` but applied to the hand keypoint detector. Total range"" between smallest and biggest scale. The scales will be centered in ratio 1. E.g., if"" scaleRange = 0.4 and scalesNumber = 2, then there will be 2 scales, 0.8 and 1.2."): flags.hpp'],['../flags_8hpp.html#a3a00f877d52f489ed93fb0db8cb8e4dc',1,'DEFINE_double(render_threshold, 0.05,"Only estimated keypoints whose score confidences are higher than this threshold will be"" rendered. Generally, a high threshold (> 0.5) will only render very clear body parts;"" while small thresholds (~0.1) will also output guessed and occluded keypoints, but also"" more false positives (i.e., wrong detections)."): flags.hpp'],['../flags_8hpp.html#ad971ae1068651177e7a78ae68c022792',1,'DEFINE_double(alpha_pose, 0.6,"Blending factor (range 0-1) for the body part rendering. 1 will show it completely, 0 will"" hide it. Only valid for GPU rendering."): flags.hpp'],['../flags_8hpp.html#a62bfc56794bb8ceaedd0eb7bc32a0f22',1,'DEFINE_double(alpha_heatmap, 0.7,"Blending factor (range 0-1) between heatmap and original frame. 1 will only show the"" heatmap, 0 will only show the frame. Only valid for GPU rendering."): flags.hpp'],['../flags_8hpp.html#a53eb4c15af968876f31ca0be54d251b3',1,'DEFINE_double(face_render_threshold, 0.4,"Analogous to `render_threshold`, but applied to the face keypoints."): flags.hpp'],['../flags_8hpp.html#af654373ad667b1683f30e350331ea709',1,'DEFINE_double(face_alpha_pose, 0.6,"Analogous to `alpha_pose` but applied to face."): flags.hpp'],['../flags_8hpp.html#a71043931875d1f5ec677fd69ae96c632',1,'DEFINE_double(face_alpha_heatmap, 0.7,"Analogous to `alpha_heatmap` but applied to face."): flags.hpp'],['../flags_8hpp.html#a6b12d681ace972ae8eede484505c50af',1,'DEFINE_double(hand_render_threshold, 0.2,"Analogous to `render_threshold`, but applied to the hand keypoints."): flags.hpp'],['../flags_8hpp.html#a890b2b8df8a57fe4e9baa465c6584ccf',1,'DEFINE_double(hand_alpha_pose, 0.6,"Analogous to `alpha_pose` but applied to hand."): flags.hpp'],['../flags_8hpp.html#ac17a7af1030d7f5bd69672fec961c083',1,'DEFINE_double(hand_alpha_heatmap, 0.7,"Analogous to `alpha_heatmap` but applied to hand."): flags.hpp'],['../flags_8hpp.html#a2fe410b6a4ab2577d0f513f5bef78699',1,'DEFINE_double(cli_verbose,-1.f,"If -1, it will be disabled (default). If it is a positive integer number, it will print on"" the command line every `verbose` frames. If number in the range (0,1), it will print the"" progress every `verbose` times the total of frames."): flags.hpp'],['../flags_8hpp.html#aba34d451bc7a9409cdb246e1d945b451',1,'DEFINE_double(write_video_fps,-1.,"Frame rate for the recorded video. By default, it will try to get the input frames producer"" frame rate (e.g., input video or webcam frame rate). If the input frames producer does not"" have a set FPS (e.g., image_dir or webcam if OpenCV not compiled with its support), set"" this value accordingly (e.g., to the frame rate displayed by the OpenPose GUI)."): flags.hpp']]], ['define_5fint32',['DEFINE_int32',['../flags_8hpp.html#a73ee51843ead02ee6358fe39dcbeffde',1,'DEFINE_int32(logging_level, 3,"The logging level. Integer in the range [0, 255]. 0 will output any log() message, while"" 255 will not output any. Current OpenPose library messages are in the range 0-4: 1 for"" low priority messages and 4 for important ones."): flags.hpp'],['../flags_8hpp.html#a8e9de971b409cfe7fdded7f0d47c502d',1,'DEFINE_int32(profile_speed, 1000,"If PROFILER_ENABLED was set in CMake or Makefile.config files, OpenPose will show some"" runtime statistics at this frame number."): flags.hpp'],['../flags_8hpp.html#a10efaeb1ea3a8478388cc7d0bfd4e59e',1,'DEFINE_int32(camera,-1,"The camera index for cv::VideoCapture. Integer in the range [0, 9]. Select a negative"" number (by default), to auto-detect and open the first available camera."): flags.hpp'],['../flags_8hpp.html#ab41c02abe3634f0db65123ecda964a31',1,'DEFINE_int32(flir_camera_index,-1,"Select -1 (default) to run on all detected flir cameras at once. Otherwise, select the flir"" camera index to run, where 0 corresponds to the detected flir camera with the lowest"" serial number, and `n` to the `n`-th lowest serial number camera."): flags.hpp'],['../flags_8hpp.html#a6c9c8a5843dd8b93e009bf29dc31cde2',1,'DEFINE_int32(frame_rotate, 0,"Rotate each frame, 4 possible values: 0, 90, 180, 270."): flags.hpp'],['../flags_8hpp.html#a284252d3d255ad5e5c35815d720fd67a',1,'DEFINE_int32(num_gpu,-1,"The number of GPU devices to use. If negative, it will use all the available GPUs in your"" machine."): flags.hpp'],['../flags_8hpp.html#a8511765700f652000f2c1c2b1a5df9f9',1,'DEFINE_int32(num_gpu_start, 0,"GPU device start number."): flags.hpp'],['../flags_8hpp.html#a485d9b07e65fe81454f5f0bdc2d33278',1,'DEFINE_int32(keypoint_scale, 0,"Scaling of the (x,y) coordinates of the final pose data array, i.e., the scale of the (x,y)"" coordinates that will be saved with the `write_json` & `write_keypoint` flags."" Select `0` to scale it to the original source resolution; `1`to scale it to the net output"" size (set with `net_resolution`); `2` to scale it to the final output size (set with"" `resolution`); `3` to scale it in the range [0,1], where (0,0) would be the top-left"" corner of the image, and (1,1) the bottom-right one; and 4 for range [-1,1], where"" (-1,-1) would be the top-left corner of the image, and (1,1) the bottom-right one. Non"" related with `scale_number` and `scale_gap`."): flags.hpp'],['../flags_8hpp.html#aa5a1826a500d7131fefb480ccd1713fb',1,'DEFINE_int32(number_people_max,-1,"This parameter will limit the maximum number of people detected, by keeping the people with"" top scores. The score is based in person area over the image, body part score, as well as"" joint score (between each pair of connected body parts). Useful if you know the exact"" number of people in the scene, so it can remove false positives (if all the people have"" been detected. However, it might also include false negatives by removing very small or"" highly occluded people. -1 will keep them all."): flags.hpp'],['../flags_8hpp.html#a1edea5f45026b353b6e6cc3b196767a0',1,'DEFINE_int32(scale_number, 1,"Number of scales to average."): flags.hpp'],['../flags_8hpp.html#aa80e5f9914dd35c852941282aa229b21',1,'DEFINE_int32(heatmaps_scale, 2,"Set 0 to scale op::Datum::poseHeatMaps in the range [-1,1], 1 for [0,1]; 2 for integer"" rounded [0,255]; and 3 for no scaling."): flags.hpp'],['../flags_8hpp.html#a311e487137e17445e6939abb7cc0cf8f',1,'DEFINE_int32(hand_scale_number, 1,"Analogous to `scale_number` but applied to the hand keypoint detector. Our best results"" were found with `hand_scale_number` = 6 and `hand_scale_range` = 0.4."): flags.hpp'],['../flags_8hpp.html#aa797dd033c6f3c4d2654e7000939d270',1,'DEFINE_int32(3d_min_views,-1,"Minimum number of views required to reconstruct each keypoint. By default (-1), it will"" require all the cameras to see the keypoint in order to reconstruct it."): flags.hpp'],['../flags_8hpp.html#a20c481950df0272f0b7b0cde67d8e72a',1,'DEFINE_int32(3d_views, 1,"Complementary option to `--image_dir` or `--video`. OpenPose will read as many images per"" iteration, allowing tasks such as stereo camera processing (`--3d`). Note that"" `--camera_parameters_folder` must be set. OpenPose must find as many `xml` files in the"" parameter folder as this number indicates."): flags.hpp'],['../flags_8hpp.html#afdfef14901f7b5e324d6983845f5ab50',1,'DEFINE_int32(tracking,-1,"Experimental, not available yet. Whether to enable people tracking across frames. The"" value indicates the number of frames where tracking is run between each OpenPose keypoint"" detection. Select -1 (default) to disable it or 0 to run simultaneously OpenPose keypoint"" detector and tracking for potentially higher accurary than only OpenPose."): flags.hpp'],['../flags_8hpp.html#a072bd893f4003b48bc7c99735eeeed39',1,'DEFINE_int32(ik_threads, 0,"Experimental, not available yet. Whether to enable inverse kinematics (IK) from 3-D"" keypoints to obtain 3-D joint angles. By default (0 threads), it is disabled. Increasing"" the number of threads will increase the speed but also the global system latency."): flags.hpp'],['../flags_8hpp.html#a4cead735de5b43cfcae5c1139df3be1a',1,'DEFINE_int32(part_to_show, 0,"Prediction channel to visualize (default: 0). 0 for all the body parts, 1-18 for each body"" part heat map, 19 for the background heat map, 20 for all the body part heat maps"" together, 21 for all the PAFs, 22-40 for each body part pair PAF."): flags.hpp'],['../flags_8hpp.html#a2aac3e05431b81d298fdbd7f701dcd5e',1,'DEFINE_int32(render_pose,-1,"Set to 0 for no rendering, 1 for CPU rendering (slightly faster), and 2 for GPU rendering"" (slower but greater functionality, e.g., `alpha_X` flags). If -1, it will pick CPU if"" CPU_ONLY is enabled, or GPU if CUDA is enabled. If rendering is enabled, it will render"" both `outputData` and `cvOutputData` with the original image and desired body part to be"" shown (i.e., keypoints, heat maps or PAFs)."): flags.hpp'],['../flags_8hpp.html#ad0269da28dc2033e23b8ea84b7e793a2',1,'DEFINE_int32(face_render,-1,"Analogous to `render_pose` but applied to the face. Extra option: -1 to use the same"" configuration that `render_pose` is using."): flags.hpp'],['../flags_8hpp.html#ada5b7fef5063818fd668359e9e0b0504',1,'DEFINE_int32(hand_render,-1,"Analogous to `render_pose` but applied to the hand. Extra option: -1 to use the same"" configuration that `render_pose` is using."): flags.hpp'],['../flags_8hpp.html#a9a34e10f75069cf3283e535a77006775',1,'DEFINE_int32(display,-1,"Display mode: -1 for automatic selection; 0 for no display (useful if there is no X server"" and/or to slightly speed up the processing if visual output is not required); 2 for 2-D"" display; 3 for 3-D display (if `--3d` enabled); and 1 for both 2-D and 3-D display."): flags.hpp'],['../flags_8hpp.html#a39756aa6d6911435a326e18541db970a',1,'DEFINE_int32(write_coco_json_variant, 0,"Currently, this option is experimental and only makes effect on car JSON generation. It"" selects the COCO variant for cocoJsonSaver."): flags.hpp']]], - ['define_5fstring',['DEFINE_string',['../flags_8hpp.html#a9e7b1394aea185360a1fe19cf4e20a89',1,'DEFINE_string(camera_resolution,"-1x-1","Set the camera resolution (either `--camera` or `--flir_camera`). `-1x-1` will use the"" default 1280x720 for `--camera`, or the maximum flir camera resolution available for"" `--flir_camera`"): flags.hpp'],['../flags_8hpp.html#aab02d4078b5f7999a582d9c5f4248676',1,'DEFINE_string(video,"","Use a video file instead of the camera. Use `examples/media/video.avi` for our default"" example video."): flags.hpp'],['../flags_8hpp.html#a7773e867133822f5601899975dc06adb',1,'DEFINE_string(image_dir,"","Process a directory of images. Use `examples/media/` for our default example folder with 20"" images. Read all standard formats (jpg, png, bmp, etc.)."): flags.hpp'],['../flags_8hpp.html#a5db17b8bc6df4fe40b556af7157dcbf7',1,'DEFINE_string(ip_camera,"","String with the IP camera URL. It supports protocols like RTSP and HTTP."): flags.hpp'],['../flags_8hpp.html#aff61246512375ff5941dc4110e127ca3',1,'DEFINE_string(camera_parameter_folder,"models/cameraParameters/flir/","String with the folder where the camera parameters are located."): flags.hpp'],['../flags_8hpp.html#a9ab689ebe20a261b20587af79123e79a',1,'DEFINE_string(model_folder,"models/","Folder path (absolute or relative) where the models (pose, face, ...) are located."): flags.hpp'],['../flags_8hpp.html#a85be61a31eaa438a7e9c7d2baf51da47',1,'DEFINE_string(output_resolution,"-1x-1","The image resolution (display and output). Use \"-1x-1\" to force the program to use the"" input image resolution."): flags.hpp'],['../flags_8hpp.html#a055e1e0a1618e96f156f32278b41d3e4',1,'DEFINE_string(model_pose,"BODY_25","Model to be used. E.g., `COCO` (18 keypoints), `MPI` (15 keypoints, ~10% faster), ""`MPI_4_layers` (15 keypoints, even faster but less accurate)."): flags.hpp'],['../flags_8hpp.html#a66d6d5c07371179c3702dbd1da9d9bd3',1,'DEFINE_string(net_resolution,"-1x368","Multiples of 16. If it is increased, the accuracy potentially increases. If it is"" decreased, the speed increases. For maximum speed-accuracy balance, it should keep the"" closest aspect ratio possible to the images or videos to be processed. Using `-1` in"" any of the dimensions, OP will choose the optimal aspect ratio depending on the user's"" input value. E.g., the default `-1x368` is equivalent to `656x368` in 16:9 resolutions,"" e.g., full HD (1980x1080) and HD (1280x720) resolutions."): flags.hpp'],['../flags_8hpp.html#af5ee5f61f0d36a03bb8647408f5e236b',1,'DEFINE_string(face_net_resolution,"368x368","Multiples of 16 and squared. Analogous to `net_resolution` but applied to the face keypoint"" detector. 320x320 usually works fine while giving a substantial speed up when multiple"" faces on the image."): flags.hpp'],['../flags_8hpp.html#afaf97bbf6a49576782d25147bc865bed',1,'DEFINE_string(hand_net_resolution,"368x368","Multiples of 16 and squared. Analogous to `net_resolution` but applied to the hand keypoint"" detector."): flags.hpp'],['../flags_8hpp.html#a7a3597e9216885470199ca1578eb7f69',1,'DEFINE_string(write_images,"","Directory to write rendered frames in `write_images_format` image format."): flags.hpp'],['../flags_8hpp.html#a6957bf419a0ca3478948a62a3ce5ecf0',1,'DEFINE_string(write_images_format,"png","File extension and format for `write_images`, e.g., png, jpg or bmp. Check the OpenCV"" function cv::imwrite for all compatible extensions."): flags.hpp'],['../flags_8hpp.html#a3051d21eb51cc39eed5f781d8eaed960',1,'DEFINE_string(write_video,"","Full file path to write rendered frames in motion JPEG video format. It might fail if the"" final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"" `camera_fps` controls FPS."): flags.hpp'],['../flags_8hpp.html#a9aa48b2ab293842bc42b96df9e97c9b8',1,'DEFINE_string(write_json,"","Directory to write OpenPose output in JSON format. It includes body, hand, and face pose"" keypoints (2-D and 3-D), as well as pose candidates (if `--part_candidates` enabled)."): flags.hpp'],['../flags_8hpp.html#a26d1c7340fc87d4593dda754d54145a2',1,'DEFINE_string(write_coco_json,"","Full file path to write people pose data with JSON COCO validation format."): flags.hpp'],['../flags_8hpp.html#ac6c2099e630e05f867ee10b43f35dc65',1,'DEFINE_string(write_coco_foot_json,"","Full file path to write people foot pose data with JSON COCO validation format."): flags.hpp'],['../flags_8hpp.html#aa3fe7c4c07492e6553a6c2d25ebd76b4',1,'DEFINE_string(write_heatmaps,"","Directory to write body pose heatmaps in PNG format. At least 1 `add_heatmaps_X` flag"" must be enabled."): flags.hpp'],['../flags_8hpp.html#a242473077549869f06534e8a9ea1ddd6',1,'DEFINE_string(write_heatmaps_format,"png","File extension and format for `write_heatmaps`, analogous to `write_images_format`."" For lossless compression, recommended `png` for integer `heatmaps_scale` and `float` for"" floating values."): flags.hpp'],['../flags_8hpp.html#ad8c5173beb83c0f9996362b3a3fba820',1,'DEFINE_string(write_keypoint,"","(Deprecated, use `write_json`) Directory to write the people pose keypoint data. Set format"" with `write_keypoint_format`."): flags.hpp'],['../flags_8hpp.html#a5aaba99bdb163516d0297d2e09dd0c7d',1,'DEFINE_string(write_keypoint_format,"yml","(Deprecated, use `write_json`) File extension and format for `write_keypoint`: json, xml,"" yaml & yml. Json not available for OpenCV < 3.0, use `write_json` instead."): flags.hpp'],['../flags_8hpp.html#ad7a48143249d608e2ad3a8413eb19c34',1,'DEFINE_string(write_video_adam,"","Experimental, not available yet. E.g., `~/Desktop/adamResult.avi`. Flag `camera_fps`"" controls FPS."): flags.hpp'],['../flags_8hpp.html#a72c09e09c94b67f88b53e1a94e7bfe0f',1,'DEFINE_string(write_bvh,"","Experimental, not available yet. E.g., `~/Desktop/mocapResult.bvh`."): flags.hpp'],['../flags_8hpp.html#a63936bd2bc53a453ba74066289ab9d29',1,'DEFINE_string(udp_host,"","Experimental, not available yet. IP for UDP communication. E.g., `192.168.0.1`."): flags.hpp'],['../flags_8hpp.html#aa7b1c758c6d6e35c3227994a9ced0236',1,'DEFINE_string(udp_port,"8051","Experimental, not available yet. Port number for UDP communication."): flags.hpp']]], + ['define_5fstring',['DEFINE_string',['../flags_8hpp.html#a9e7b1394aea185360a1fe19cf4e20a89',1,'DEFINE_string(camera_resolution,"-1x-1","Set the camera resolution (either `--camera` or `--flir_camera`). `-1x-1` will use the"" default 1280x720 for `--camera`, or the maximum flir camera resolution available for"" `--flir_camera`"): flags.hpp'],['../flags_8hpp.html#aab02d4078b5f7999a582d9c5f4248676',1,'DEFINE_string(video,"","Use a video file instead of the camera. Use `examples/media/video.avi` for our default"" example video."): flags.hpp'],['../flags_8hpp.html#a7773e867133822f5601899975dc06adb',1,'DEFINE_string(image_dir,"","Process a directory of images. Use `examples/media/` for our default example folder with 20"" images. Read all standard formats (jpg, png, bmp, etc.)."): flags.hpp'],['../flags_8hpp.html#a5db17b8bc6df4fe40b556af7157dcbf7',1,'DEFINE_string(ip_camera,"","String with the IP camera URL. It supports protocols like RTSP and HTTP."): flags.hpp'],['../flags_8hpp.html#aff61246512375ff5941dc4110e127ca3',1,'DEFINE_string(camera_parameter_folder,"models/cameraParameters/flir/","String with the folder where the camera parameters are located."): flags.hpp'],['../flags_8hpp.html#a9ab689ebe20a261b20587af79123e79a',1,'DEFINE_string(model_folder,"models/","Folder path (absolute or relative) where the models (pose, face, ...) are located."): flags.hpp'],['../flags_8hpp.html#a85be61a31eaa438a7e9c7d2baf51da47',1,'DEFINE_string(output_resolution,"-1x-1","The image resolution (display and output). Use \"-1x-1\" to force the program to use the"" input image resolution."): flags.hpp'],['../flags_8hpp.html#a055e1e0a1618e96f156f32278b41d3e4',1,'DEFINE_string(model_pose,"BODY_25","Model to be used. E.g., `COCO` (18 keypoints), `MPI` (15 keypoints, ~10% faster), ""`MPI_4_layers` (15 keypoints, even faster but less accurate)."): flags.hpp'],['../flags_8hpp.html#a66d6d5c07371179c3702dbd1da9d9bd3',1,'DEFINE_string(net_resolution,"-1x368","Multiples of 16. If it is increased, the accuracy potentially increases. If it is"" decreased, the speed increases. For maximum speed-accuracy balance, it should keep the"" closest aspect ratio possible to the images or videos to be processed. Using `-1` in"" any of the dimensions, OP will choose the optimal aspect ratio depending on the user's"" input value. E.g., the default `-1x368` is equivalent to `656x368` in 16:9 resolutions,"" e.g., full HD (1980x1080) and HD (1280x720) resolutions."): flags.hpp'],['../flags_8hpp.html#af5ee5f61f0d36a03bb8647408f5e236b',1,'DEFINE_string(face_net_resolution,"368x368","Multiples of 16 and squared. Analogous to `net_resolution` but applied to the face keypoint"" detector. 320x320 usually works fine while giving a substantial speed up when multiple"" faces on the image."): flags.hpp'],['../flags_8hpp.html#afaf97bbf6a49576782d25147bc865bed',1,'DEFINE_string(hand_net_resolution,"368x368","Multiples of 16 and squared. Analogous to `net_resolution` but applied to the hand keypoint"" detector."): flags.hpp'],['../flags_8hpp.html#a7a3597e9216885470199ca1578eb7f69',1,'DEFINE_string(write_images,"","Directory to write rendered frames in `write_images_format` image format."): flags.hpp'],['../flags_8hpp.html#a6957bf419a0ca3478948a62a3ce5ecf0',1,'DEFINE_string(write_images_format,"png","File extension and format for `write_images`, e.g., png, jpg or bmp. Check the OpenCV"" function cv::imwrite for all compatible extensions."): flags.hpp'],['../flags_8hpp.html#a2473e551c10d8627471382b70fbb838e',1,'DEFINE_string(write_video,"","Full file path to write rendered frames in motion JPEG video format. It might fail if the"" final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"" `write_video_fps` controls FPS."): flags.hpp'],['../flags_8hpp.html#a9aa48b2ab293842bc42b96df9e97c9b8',1,'DEFINE_string(write_json,"","Directory to write OpenPose output in JSON format. It includes body, hand, and face pose"" keypoints (2-D and 3-D), as well as pose candidates (if `--part_candidates` enabled)."): flags.hpp'],['../flags_8hpp.html#a26d1c7340fc87d4593dda754d54145a2',1,'DEFINE_string(write_coco_json,"","Full file path to write people pose data with JSON COCO validation format."): flags.hpp'],['../flags_8hpp.html#ac6c2099e630e05f867ee10b43f35dc65',1,'DEFINE_string(write_coco_foot_json,"","Full file path to write people foot pose data with JSON COCO validation format."): flags.hpp'],['../flags_8hpp.html#aa3fe7c4c07492e6553a6c2d25ebd76b4',1,'DEFINE_string(write_heatmaps,"","Directory to write body pose heatmaps in PNG format. At least 1 `add_heatmaps_X` flag"" must be enabled."): flags.hpp'],['../flags_8hpp.html#a242473077549869f06534e8a9ea1ddd6',1,'DEFINE_string(write_heatmaps_format,"png","File extension and format for `write_heatmaps`, analogous to `write_images_format`."" For lossless compression, recommended `png` for integer `heatmaps_scale` and `float` for"" floating values."): flags.hpp'],['../flags_8hpp.html#ad8c5173beb83c0f9996362b3a3fba820',1,'DEFINE_string(write_keypoint,"","(Deprecated, use `write_json`) Directory to write the people pose keypoint data. Set format"" with `write_keypoint_format`."): flags.hpp'],['../flags_8hpp.html#a5aaba99bdb163516d0297d2e09dd0c7d',1,'DEFINE_string(write_keypoint_format,"yml","(Deprecated, use `write_json`) File extension and format for `write_keypoint`: json, xml,"" yaml & yml. Json not available for OpenCV < 3.0, use `write_json` instead."): flags.hpp'],['../flags_8hpp.html#a26f9e4bae967b528e221c40d21cad543',1,'DEFINE_string(write_video_adam,"","Experimental, not available yet. E.g., `~/Desktop/adamResult.avi`. Flag `write_video_fps`"" controls FPS."): flags.hpp'],['../flags_8hpp.html#a72c09e09c94b67f88b53e1a94e7bfe0f',1,'DEFINE_string(write_bvh,"","Experimental, not available yet. E.g., `~/Desktop/mocapResult.bvh`."): flags.hpp'],['../flags_8hpp.html#a63936bd2bc53a453ba74066289ab9d29',1,'DEFINE_string(udp_host,"","Experimental, not available yet. IP for UDP communication. E.g., `192.168.0.1`."): flags.hpp'],['../flags_8hpp.html#aa7b1c758c6d6e35c3227994a9ced0236',1,'DEFINE_string(udp_port,"8051","Experimental, not available yet. Port number for UDP communication."): flags.hpp']]], ['define_5ftemplate_5fdatum',['DEFINE_TEMPLATE_DATUM',['../datum_8hpp.html#ad11d52b69bc54e48ceb2f5787f700431',1,'datum.hpp']]], ['define_5fuint64',['DEFINE_uint64',['../flags_8hpp.html#a89127a571b2b18ba05912d7b06ffb2ef',1,'DEFINE_uint64(frame_first, 0,"Start on desired frame number. Indexes are 0-based, i.e., the first frame has index 0."): flags.hpp'],['../flags_8hpp.html#a22572531e5a4896c510639ac57cf522c',1,'DEFINE_uint64(frame_step, 1,"Step or gap between processed frames. E.g., `--frame_step 5` would read and process frames"" 0, 5, 10, etc.."): flags.hpp'],['../flags_8hpp.html#a158227abc2af90abaec523a784b40fa8',1,'DEFINE_uint64(frame_last,-1,"Finish on desired frame number. Select -1 to disable. Indexes are 0-based, e.g., if set to"" 10, it will process 11 frames (0-10)."): flags.hpp']]], ['delete_5fcopy',['DELETE_COPY',['../classop_1_1_face_cpu_renderer.html#a233f2a83930d07e4d420b43c8a660f32',1,'op::FaceCpuRenderer::DELETE_COPY()'],['../classop_1_1_hand_cpu_renderer.html#a66a7d318b240c73687320bf092363409',1,'op::HandCpuRenderer::DELETE_COPY()'],['../classop_1_1_sub_thread_no_queue.html#a43504502c36461305d656fb87b914749',1,'op::SubThreadNoQueue::DELETE_COPY()'],['../macros_8hpp.html#abef96b5dd35dd9d44ad27ddf0e2f5f2e',1,'DELETE_COPY(): macros.hpp']]], diff --git a/html/search/functions_16.js b/html/search/functions_16.js index 7f3ed8fb..9fa942f5 100644 --- a/html/search/functions_16.js +++ b/html/search/functions_16.js @@ -9,7 +9,7 @@ var searchData= ['wcvmattoopinput',['WCvMatToOpInput',['../classop_1_1_w_cv_mat_to_op_input.html#a82c13641d071fdb5db50afdee7cfa849',1,'op::WCvMatToOpInput']]], ['wcvmattoopoutput',['WCvMatToOpOutput',['../classop_1_1_w_cv_mat_to_op_output.html#a04cd3d8e91d731a36e3c7830631e47af',1,'op::WCvMatToOpOutput']]], ['wdatumproducer',['WDatumProducer',['../classop_1_1_w_datum_producer.html#aaba921d1cf641dc44ab509c0e460c5f1',1,'op::WDatumProducer']]], - ['webcamreader',['WebcamReader',['../classop_1_1_webcam_reader.html#afbfa9ebf32ab1c95f0378b49fce0df35',1,'op::WebcamReader']]], + ['webcamreader',['WebcamReader',['../classop_1_1_webcam_reader.html#ab6709f433122e783f87db1004e6666f4',1,'op::WebcamReader']]], ['wfacedetector',['WFaceDetector',['../classop_1_1_w_face_detector.html#a77355426bc59b212a8eb1730ff6289f3',1,'op::WFaceDetector']]], ['wfacedetectoropencv',['WFaceDetectorOpenCV',['../classop_1_1_w_face_detector_open_c_v.html#a8c765201f0cc9440f8d172c8d8c76a62',1,'op::WFaceDetectorOpenCV']]], ['wfaceextractornet',['WFaceExtractorNet',['../classop_1_1_w_face_extractor_net.html#a31bd32d4b9922ea456c97343c94501ac',1,'op::WFaceExtractorNet']]], @@ -51,8 +51,8 @@ var searchData= ['wrapperstructface',['WrapperStructFace',['../structop_1_1_wrapper_struct_face.html#ac60accbce8d798adbc3b8a76e6e4f879',1,'op::WrapperStructFace']]], ['wrapperstructgui',['WrapperStructGui',['../structop_1_1_wrapper_struct_gui.html#a41638659ae2237d4ebfac635f4cc7842',1,'op::WrapperStructGui']]], ['wrapperstructhand',['WrapperStructHand',['../structop_1_1_wrapper_struct_hand.html#aaa42d271c3cb7fa3a071d4785644c0a8',1,'op::WrapperStructHand']]], - ['wrapperstructinput',['WrapperStructInput',['../structop_1_1_wrapper_struct_input.html#a529d945c83bb69ac1db7b8db371e6622',1,'op::WrapperStructInput']]], - ['wrapperstructoutput',['WrapperStructOutput',['../structop_1_1_wrapper_struct_output.html#a429cbf2dbb9464ad6c5937033211c928',1,'op::WrapperStructOutput']]], + ['wrapperstructinput',['WrapperStructInput',['../structop_1_1_wrapper_struct_input.html#a55839a660d5259c5a4adb0639bdf156d',1,'op::WrapperStructInput']]], + ['wrapperstructoutput',['WrapperStructOutput',['../structop_1_1_wrapper_struct_output.html#af12d5e43eef90a3c0f8cc0b0d805b313',1,'op::WrapperStructOutput']]], ['wrapperstructpose',['WrapperStructPose',['../structop_1_1_wrapper_struct_pose.html#a17b6f8cf237c7b0399c65d432188165a',1,'op::WrapperStructPose']]], ['wrappert',['WrapperT',['../classop_1_1_wrapper_t.html#af1a56f0542a2cbcc11d6b185adeb5626',1,'op::WrapperT']]], ['write',['write',['../classop_1_1_video_saver.html#a7c79397b9be8b6d6d12b9f3e78e6c794',1,'op::VideoSaver::write(const cv::Mat &cvMat)'],['../classop_1_1_video_saver.html#a3cdbef8bada237edffaf7793eaa0fe8e',1,'op::VideoSaver::write(const std::vector< cv::Mat > &cvMats)']]], diff --git a/html/search/functions_2.js b/html/search/functions_2.js index 089723c2..04af090b 100644 --- a/html/search/functions_2.js +++ b/html/search/functions_2.js @@ -33,7 +33,7 @@ var searchData= ['createarray',['createArray',['../classop_1_1_cv_mat_to_op_input.html#acf0c43174fe8e3b1c71d76aca861a6ab',1,'op::CvMatToOpInput::createArray()'],['../classop_1_1_cv_mat_to_op_output.html#a003515873bf34525e2a6d313d8619ff3',1,'op::CvMatToOpOutput::createArray()']]], ['createkernels',['createKernels',['../classcl_1_1_program.html#a8251f8a862bdfd82caf10a949b2bd884',1,'cl::Program']]], ['createpeoplevector',['createPeopleVector',['../namespaceop.html#ae9cb91cf03ed561a31b9f4c950926731',1,'op']]], - ['createproducer',['createProducer',['../namespaceop.html#aff1530aa4f78f3c55b7df9b452ceee94',1,'op']]], + ['createproducer',['createProducer',['../namespaceop.html#a70c5ea34fa5f283a820c6090c674cbc7',1,'op']]], ['createsubbuffer',['createSubBuffer',['../classcl_1_1_buffer.html#ab73f1e0ab2224f3d515820dd6b0c1d73',1,'cl::Buffer']]], ['createsubdevices',['createSubDevices',['../classcl_1_1_device.html#ab60bfd190bf8f82cb8f0adb0a869a2f2',1,'cl::Device']]], ['cudacheck',['cudaCheck',['../namespaceop.html#a2af8422ada0de882cc222920ca15c6d2',1,'op']]], diff --git a/html/search/functions_3.js b/html/search/functions_3.js index b4076c2a..9d81a4ae 100644 --- a/html/search/functions_3.js +++ b/html/search/functions_3.js @@ -5,9 +5,9 @@ var searchData= ['datumproducer',['DatumProducer',['../classop_1_1_datum_producer.html#a308c34ca52e7d6db2d85e27a348a15bd',1,'op::DatumProducer']]], ['deallocate',['deallocate',['../classcl_1_1_s_v_m_allocator.html#a695f4693c4245c66285e7f4a0405cf84',1,'cl::SVMAllocator']]], ['define_5fbool',['DEFINE_bool',['../flags_8hpp.html#a035ba7d578f36103d096569f1984ab61',1,'DEFINE_bool(disable_multi_thread, false,"It would slightly reduce the frame rate in order to highly reduce the lag. Mainly useful"" for 1) Cases where it is needed a low latency (e.g., webcam in real-time scenarios with"" low-range GPU devices); and 2) Debugging OpenPose when it is crashing to locate the"" error."): flags.hpp'],['../flags_8hpp.html#a7fc3e871114ac35447499ffda035d51e',1,'DEFINE_bool(flir_camera, false,"Whether to use FLIR (Point-Grey) stereo camera."): flags.hpp'],['../flags_8hpp.html#a9d45877ef21b9042f1b307d23d404e40',1,'DEFINE_bool(frame_flip, false,"Flip/mirror each frame (e.g., for real time webcam demonstrations)."): flags.hpp'],['../flags_8hpp.html#a6a501f229de1ba19801b77fd0565527b',1,'DEFINE_bool(frames_repeat, false,"Repeat frames when finished."): flags.hpp'],['../flags_8hpp.html#a5e350d38962a702d8e0c658fbbb5cc64',1,'DEFINE_bool(process_real_time, false,"Enable to keep the original source frame rate (e.g., for video). If the processing time is"" too long, it will skip frames. If it is too fast, it will slow it down."): flags.hpp'],['../flags_8hpp.html#ad739178d4295e31edd2f1e468bd2e600',1,'DEFINE_bool(frame_keep_distortion, false,"If false (default), it will undistortionate the image based on the"" `camera_parameter_folder` camera parameters; if true, it will not undistortionate, i.e.,"" it will leave it as it is."): flags.hpp'],['../flags_8hpp.html#a8d76e63210ddd6541cb8b030df0c09cf',1,'DEFINE_bool(maximize_positives, false,"It reduces the thresholds to accept a person candidate. It highly increases both false and"" true positives. I.e., it maximizes average recall but could harm average precision."): flags.hpp'],['../flags_8hpp.html#a5e8200fc5fd8bc1e80b94b029ea8e18d',1,'DEFINE_bool(body_disable, false,"Disable body keypoint detection. Option only possible for faster (but less accurate) face"" keypoint detection."): flags.hpp'],['../flags_8hpp.html#a669c6f4820af0275f40808b18147b98c',1,'DEFINE_bool(heatmaps_add_parts, false,"If true, it will fill op::Datum::poseHeatMaps array with the body part heatmaps, and"" analogously face & hand heatmaps to op::Datum::faceHeatMaps & op::Datum::handHeatMaps."" If more than one `add_heatmaps_X` flag is enabled, it will place then in sequential"" memory order: body parts + bkg + PAFs. It will follow the order on"" POSE_BODY_PART_MAPPING in `src/openpose/pose/poseParameters.cpp`. Program speed will"" considerably decrease. Not required for OpenPose, enable it only if you intend to"" explicitly use this information later."): flags.hpp'],['../flags_8hpp.html#af57ca90aafa15b707af299527b0aff6f',1,'DEFINE_bool(heatmaps_add_bkg, false,"Same functionality as `add_heatmaps_parts`, but adding the heatmap corresponding to"" background."): flags.hpp'],['../flags_8hpp.html#ac881df85c5be736d05822ad98ac0496f',1,'DEFINE_bool(heatmaps_add_PAFs, false,"Same functionality as `add_heatmaps_parts`, but adding the PAFs."): flags.hpp'],['../flags_8hpp.html#ab30cdb2253e3ea76aa474424e87075eb',1,'DEFINE_bool(part_candidates, false,"Also enable `write_json` in order to save this information. If true, it will fill the"" op::Datum::poseCandidates array with the body part candidates. Candidates refer to all"" the detected body parts, before being assembled into people. Note that the number of"" candidates is equal or higher than the number of final body parts (i.e., after being"" assembled into people). The empty body parts are filled with 0s. Program speed will"" slightly decrease. Not required for OpenPose, enable it only if you intend to explicitly"" use this information."): flags.hpp'],['../flags_8hpp.html#aea11a0489c2af278990d3ddff10960fd',1,'DEFINE_bool(face, false,"Enables face keypoint detection. It will share some parameters from the body pose, e.g."" `model_folder`. Note that this will considerable slow down the performance and increse"" the required GPU memory. In addition, the greater number of people on the image, the"" slower OpenPose will be."): flags.hpp'],['../flags_8hpp.html#a4da8f1bc0afb58f2a757ab6d90c6042e',1,'DEFINE_bool(hand, false,"Enables hand keypoint detection. It will share some parameters from the body pose, e.g."" `model_folder`. Analogously to `--face`, it will also slow down the performance, increase"" the required GPU memory and its speed depends on the number of people."): flags.hpp'],['../flags_8hpp.html#a3135e093746d3a75b88eb7fb5d0d35e4',1,'DEFINE_bool(hand_tracking, false,"Adding hand tracking might improve hand keypoints detection for webcam (if the frame rate"" is high enough, i.e., >7 FPS per GPU) and video. This is not person ID tracking, it"" simply looks for hands in positions at which hands were located in previous frames, but"" it does not guarantee the same person ID among frames."): flags.hpp'],['../flags_8hpp.html#a4c800b6a91b02874d006da33ab8432cd',1,'DEFINE_bool(3d, false,"Running OpenPose 3-D reconstruction demo: 1) Reading from a stereo camera system."" 2) Performing 3-D reconstruction from the multiple views. 3) Displaying 3-D reconstruction"" results. Note that it will only display 1 person. If multiple people is present, it will"" fail."): flags.hpp'],['../flags_8hpp.html#ac210b56a3c46ff06143a62b0bb725cc6',1,'DEFINE_bool(identification, false,"Experimental, not available yet. Whether to enable people identification across frames."): flags.hpp'],['../flags_8hpp.html#a1a9ffc302eac69c8ba024da3edf01a5f',1,'DEFINE_bool(disable_blending, false,"If enabled, it will render the results (keypoint skeletons or heatmaps) on a black"" background, instead of being rendered into the original image. Related: `part_to_show`,"" `alpha_pose`, and `alpha_pose`."): flags.hpp'],['../flags_8hpp.html#a231bec7b2113f31cebb760c849ca2841',1,'DEFINE_bool(fullscreen, false,"Run in full-screen mode (press f during runtime to toggle)."): flags.hpp'],['../flags_8hpp.html#a0ee4f86d572ef52ec26dcbb37efb5e65',1,'DEFINE_bool(no_gui_verbose, false,"Do not write text on output images on GUI (e.g., number of current frame and people). It"" does not affect the pose rendering."): flags.hpp']]], - ['define_5fdouble',['DEFINE_double',['../flags_8hpp.html#a29f9621cd9361deec9512f8d8b53e6ba',1,'DEFINE_double(camera_fps, 30.0,"Frame rate for the webcam (also used when saving video). Set this value to the minimum"" value between the OpenPose displayed speed and the webcam real frame rate."): flags.hpp'],['../flags_8hpp.html#adf35e9261afec1673a42de6197f07f42',1,'DEFINE_double(scale_gap, 0.3,"Scale gap between scales. No effect unless scale_number > 1. Initial scale is always 1."" If you want to change the initial scale, you actually want to multiply the"" `net_resolution` by your desired initial scale."): flags.hpp'],['../flags_8hpp.html#abf5c8a05ae8f86c8e4d8eedbceb84516',1,'DEFINE_double(hand_scale_range, 0.4,"Analogous purpose than `scale_gap` but applied to the hand keypoint detector. Total range"" between smallest and biggest scale. The scales will be centered in ratio 1. E.g., if"" scaleRange = 0.4 and scalesNumber = 2, then there will be 2 scales, 0.8 and 1.2."): flags.hpp'],['../flags_8hpp.html#a3a00f877d52f489ed93fb0db8cb8e4dc',1,'DEFINE_double(render_threshold, 0.05,"Only estimated keypoints whose score confidences are higher than this threshold will be"" rendered. Generally, a high threshold (> 0.5) will only render very clear body parts;"" while small thresholds (~0.1) will also output guessed and occluded keypoints, but also"" more false positives (i.e., wrong detections)."): flags.hpp'],['../flags_8hpp.html#ad971ae1068651177e7a78ae68c022792',1,'DEFINE_double(alpha_pose, 0.6,"Blending factor (range 0-1) for the body part rendering. 1 will show it completely, 0 will"" hide it. Only valid for GPU rendering."): flags.hpp'],['../flags_8hpp.html#a62bfc56794bb8ceaedd0eb7bc32a0f22',1,'DEFINE_double(alpha_heatmap, 0.7,"Blending factor (range 0-1) between heatmap and original frame. 1 will only show the"" heatmap, 0 will only show the frame. Only valid for GPU rendering."): flags.hpp'],['../flags_8hpp.html#a53eb4c15af968876f31ca0be54d251b3',1,'DEFINE_double(face_render_threshold, 0.4,"Analogous to `render_threshold`, but applied to the face keypoints."): flags.hpp'],['../flags_8hpp.html#af654373ad667b1683f30e350331ea709',1,'DEFINE_double(face_alpha_pose, 0.6,"Analogous to `alpha_pose` but applied to face."): flags.hpp'],['../flags_8hpp.html#a71043931875d1f5ec677fd69ae96c632',1,'DEFINE_double(face_alpha_heatmap, 0.7,"Analogous to `alpha_heatmap` but applied to face."): flags.hpp'],['../flags_8hpp.html#a6b12d681ace972ae8eede484505c50af',1,'DEFINE_double(hand_render_threshold, 0.2,"Analogous to `render_threshold`, but applied to the hand keypoints."): flags.hpp'],['../flags_8hpp.html#a890b2b8df8a57fe4e9baa465c6584ccf',1,'DEFINE_double(hand_alpha_pose, 0.6,"Analogous to `alpha_pose` but applied to hand."): flags.hpp'],['../flags_8hpp.html#ac17a7af1030d7f5bd69672fec961c083',1,'DEFINE_double(hand_alpha_heatmap, 0.7,"Analogous to `alpha_heatmap` but applied to hand."): flags.hpp'],['../flags_8hpp.html#a2fe410b6a4ab2577d0f513f5bef78699',1,'DEFINE_double(cli_verbose,-1.f,"If -1, it will be disabled (default). If it is a positive integer number, it will print on"" the command line every `verbose` frames. If number in the range (0,1), it will print the"" progress every `verbose` times the total of frames."): flags.hpp']]], + ['define_5fdouble',['DEFINE_double',['../flags_8hpp.html#adf35e9261afec1673a42de6197f07f42',1,'DEFINE_double(scale_gap, 0.3,"Scale gap between scales. No effect unless scale_number > 1. Initial scale is always 1."" If you want to change the initial scale, you actually want to multiply the"" `net_resolution` by your desired initial scale."): flags.hpp'],['../flags_8hpp.html#abf5c8a05ae8f86c8e4d8eedbceb84516',1,'DEFINE_double(hand_scale_range, 0.4,"Analogous purpose than `scale_gap` but applied to the hand keypoint detector. Total range"" between smallest and biggest scale. The scales will be centered in ratio 1. E.g., if"" scaleRange = 0.4 and scalesNumber = 2, then there will be 2 scales, 0.8 and 1.2."): flags.hpp'],['../flags_8hpp.html#a3a00f877d52f489ed93fb0db8cb8e4dc',1,'DEFINE_double(render_threshold, 0.05,"Only estimated keypoints whose score confidences are higher than this threshold will be"" rendered. Generally, a high threshold (> 0.5) will only render very clear body parts;"" while small thresholds (~0.1) will also output guessed and occluded keypoints, but also"" more false positives (i.e., wrong detections)."): flags.hpp'],['../flags_8hpp.html#ad971ae1068651177e7a78ae68c022792',1,'DEFINE_double(alpha_pose, 0.6,"Blending factor (range 0-1) for the body part rendering. 1 will show it completely, 0 will"" hide it. Only valid for GPU rendering."): flags.hpp'],['../flags_8hpp.html#a62bfc56794bb8ceaedd0eb7bc32a0f22',1,'DEFINE_double(alpha_heatmap, 0.7,"Blending factor (range 0-1) between heatmap and original frame. 1 will only show the"" heatmap, 0 will only show the frame. Only valid for GPU rendering."): flags.hpp'],['../flags_8hpp.html#a53eb4c15af968876f31ca0be54d251b3',1,'DEFINE_double(face_render_threshold, 0.4,"Analogous to `render_threshold`, but applied to the face keypoints."): flags.hpp'],['../flags_8hpp.html#af654373ad667b1683f30e350331ea709',1,'DEFINE_double(face_alpha_pose, 0.6,"Analogous to `alpha_pose` but applied to face."): flags.hpp'],['../flags_8hpp.html#a71043931875d1f5ec677fd69ae96c632',1,'DEFINE_double(face_alpha_heatmap, 0.7,"Analogous to `alpha_heatmap` but applied to face."): flags.hpp'],['../flags_8hpp.html#a6b12d681ace972ae8eede484505c50af',1,'DEFINE_double(hand_render_threshold, 0.2,"Analogous to `render_threshold`, but applied to the hand keypoints."): flags.hpp'],['../flags_8hpp.html#a890b2b8df8a57fe4e9baa465c6584ccf',1,'DEFINE_double(hand_alpha_pose, 0.6,"Analogous to `alpha_pose` but applied to hand."): flags.hpp'],['../flags_8hpp.html#ac17a7af1030d7f5bd69672fec961c083',1,'DEFINE_double(hand_alpha_heatmap, 0.7,"Analogous to `alpha_heatmap` but applied to hand."): flags.hpp'],['../flags_8hpp.html#a2fe410b6a4ab2577d0f513f5bef78699',1,'DEFINE_double(cli_verbose,-1.f,"If -1, it will be disabled (default). If it is a positive integer number, it will print on"" the command line every `verbose` frames. If number in the range (0,1), it will print the"" progress every `verbose` times the total of frames."): flags.hpp'],['../flags_8hpp.html#aba34d451bc7a9409cdb246e1d945b451',1,'DEFINE_double(write_video_fps,-1.,"Frame rate for the recorded video. By default, it will try to get the input frames producer"" frame rate (e.g., input video or webcam frame rate). If the input frames producer does not"" have a set FPS (e.g., image_dir or webcam if OpenCV not compiled with its support), set"" this value accordingly (e.g., to the frame rate displayed by the OpenPose GUI)."): flags.hpp']]], ['define_5fint32',['DEFINE_int32',['../flags_8hpp.html#a73ee51843ead02ee6358fe39dcbeffde',1,'DEFINE_int32(logging_level, 3,"The logging level. Integer in the range [0, 255]. 0 will output any log() message, while"" 255 will not output any. Current OpenPose library messages are in the range 0-4: 1 for"" low priority messages and 4 for important ones."): flags.hpp'],['../flags_8hpp.html#a8e9de971b409cfe7fdded7f0d47c502d',1,'DEFINE_int32(profile_speed, 1000,"If PROFILER_ENABLED was set in CMake or Makefile.config files, OpenPose will show some"" runtime statistics at this frame number."): flags.hpp'],['../flags_8hpp.html#a10efaeb1ea3a8478388cc7d0bfd4e59e',1,'DEFINE_int32(camera,-1,"The camera index for cv::VideoCapture. Integer in the range [0, 9]. Select a negative"" number (by default), to auto-detect and open the first available camera."): flags.hpp'],['../flags_8hpp.html#ab41c02abe3634f0db65123ecda964a31',1,'DEFINE_int32(flir_camera_index,-1,"Select -1 (default) to run on all detected flir cameras at once. Otherwise, select the flir"" camera index to run, where 0 corresponds to the detected flir camera with the lowest"" serial number, and `n` to the `n`-th lowest serial number camera."): flags.hpp'],['../flags_8hpp.html#a6c9c8a5843dd8b93e009bf29dc31cde2',1,'DEFINE_int32(frame_rotate, 0,"Rotate each frame, 4 possible values: 0, 90, 180, 270."): flags.hpp'],['../flags_8hpp.html#a284252d3d255ad5e5c35815d720fd67a',1,'DEFINE_int32(num_gpu,-1,"The number of GPU devices to use. If negative, it will use all the available GPUs in your"" machine."): flags.hpp'],['../flags_8hpp.html#a8511765700f652000f2c1c2b1a5df9f9',1,'DEFINE_int32(num_gpu_start, 0,"GPU device start number."): flags.hpp'],['../flags_8hpp.html#a485d9b07e65fe81454f5f0bdc2d33278',1,'DEFINE_int32(keypoint_scale, 0,"Scaling of the (x,y) coordinates of the final pose data array, i.e., the scale of the (x,y)"" coordinates that will be saved with the `write_json` & `write_keypoint` flags."" Select `0` to scale it to the original source resolution; `1`to scale it to the net output"" size (set with `net_resolution`); `2` to scale it to the final output size (set with"" `resolution`); `3` to scale it in the range [0,1], where (0,0) would be the top-left"" corner of the image, and (1,1) the bottom-right one; and 4 for range [-1,1], where"" (-1,-1) would be the top-left corner of the image, and (1,1) the bottom-right one. Non"" related with `scale_number` and `scale_gap`."): flags.hpp'],['../flags_8hpp.html#aa5a1826a500d7131fefb480ccd1713fb',1,'DEFINE_int32(number_people_max,-1,"This parameter will limit the maximum number of people detected, by keeping the people with"" top scores. The score is based in person area over the image, body part score, as well as"" joint score (between each pair of connected body parts). Useful if you know the exact"" number of people in the scene, so it can remove false positives (if all the people have"" been detected. However, it might also include false negatives by removing very small or"" highly occluded people. -1 will keep them all."): flags.hpp'],['../flags_8hpp.html#a1edea5f45026b353b6e6cc3b196767a0',1,'DEFINE_int32(scale_number, 1,"Number of scales to average."): flags.hpp'],['../flags_8hpp.html#aa80e5f9914dd35c852941282aa229b21',1,'DEFINE_int32(heatmaps_scale, 2,"Set 0 to scale op::Datum::poseHeatMaps in the range [-1,1], 1 for [0,1]; 2 for integer"" rounded [0,255]; and 3 for no scaling."): flags.hpp'],['../flags_8hpp.html#a311e487137e17445e6939abb7cc0cf8f',1,'DEFINE_int32(hand_scale_number, 1,"Analogous to `scale_number` but applied to the hand keypoint detector. Our best results"" were found with `hand_scale_number` = 6 and `hand_scale_range` = 0.4."): flags.hpp'],['../flags_8hpp.html#aa797dd033c6f3c4d2654e7000939d270',1,'DEFINE_int32(3d_min_views,-1,"Minimum number of views required to reconstruct each keypoint. By default (-1), it will"" require all the cameras to see the keypoint in order to reconstruct it."): flags.hpp'],['../flags_8hpp.html#a20c481950df0272f0b7b0cde67d8e72a',1,'DEFINE_int32(3d_views, 1,"Complementary option to `--image_dir` or `--video`. OpenPose will read as many images per"" iteration, allowing tasks such as stereo camera processing (`--3d`). Note that"" `--camera_parameters_folder` must be set. OpenPose must find as many `xml` files in the"" parameter folder as this number indicates."): flags.hpp'],['../flags_8hpp.html#afdfef14901f7b5e324d6983845f5ab50',1,'DEFINE_int32(tracking,-1,"Experimental, not available yet. Whether to enable people tracking across frames. The"" value indicates the number of frames where tracking is run between each OpenPose keypoint"" detection. Select -1 (default) to disable it or 0 to run simultaneously OpenPose keypoint"" detector and tracking for potentially higher accurary than only OpenPose."): flags.hpp'],['../flags_8hpp.html#a072bd893f4003b48bc7c99735eeeed39',1,'DEFINE_int32(ik_threads, 0,"Experimental, not available yet. Whether to enable inverse kinematics (IK) from 3-D"" keypoints to obtain 3-D joint angles. By default (0 threads), it is disabled. Increasing"" the number of threads will increase the speed but also the global system latency."): flags.hpp'],['../flags_8hpp.html#a4cead735de5b43cfcae5c1139df3be1a',1,'DEFINE_int32(part_to_show, 0,"Prediction channel to visualize (default: 0). 0 for all the body parts, 1-18 for each body"" part heat map, 19 for the background heat map, 20 for all the body part heat maps"" together, 21 for all the PAFs, 22-40 for each body part pair PAF."): flags.hpp'],['../flags_8hpp.html#a2aac3e05431b81d298fdbd7f701dcd5e',1,'DEFINE_int32(render_pose,-1,"Set to 0 for no rendering, 1 for CPU rendering (slightly faster), and 2 for GPU rendering"" (slower but greater functionality, e.g., `alpha_X` flags). If -1, it will pick CPU if"" CPU_ONLY is enabled, or GPU if CUDA is enabled. If rendering is enabled, it will render"" both `outputData` and `cvOutputData` with the original image and desired body part to be"" shown (i.e., keypoints, heat maps or PAFs)."): flags.hpp'],['../flags_8hpp.html#ad0269da28dc2033e23b8ea84b7e793a2',1,'DEFINE_int32(face_render,-1,"Analogous to `render_pose` but applied to the face. Extra option: -1 to use the same"" configuration that `render_pose` is using."): flags.hpp'],['../flags_8hpp.html#ada5b7fef5063818fd668359e9e0b0504',1,'DEFINE_int32(hand_render,-1,"Analogous to `render_pose` but applied to the hand. Extra option: -1 to use the same"" configuration that `render_pose` is using."): flags.hpp'],['../flags_8hpp.html#a9a34e10f75069cf3283e535a77006775',1,'DEFINE_int32(display,-1,"Display mode: -1 for automatic selection; 0 for no display (useful if there is no X server"" and/or to slightly speed up the processing if visual output is not required); 2 for 2-D"" display; 3 for 3-D display (if `--3d` enabled); and 1 for both 2-D and 3-D display."): flags.hpp'],['../flags_8hpp.html#a39756aa6d6911435a326e18541db970a',1,'DEFINE_int32(write_coco_json_variant, 0,"Currently, this option is experimental and only makes effect on car JSON generation. It"" selects the COCO variant for cocoJsonSaver."): flags.hpp']]], - ['define_5fstring',['DEFINE_string',['../flags_8hpp.html#a9e7b1394aea185360a1fe19cf4e20a89',1,'DEFINE_string(camera_resolution,"-1x-1","Set the camera resolution (either `--camera` or `--flir_camera`). `-1x-1` will use the"" default 1280x720 for `--camera`, or the maximum flir camera resolution available for"" `--flir_camera`"): flags.hpp'],['../flags_8hpp.html#aab02d4078b5f7999a582d9c5f4248676',1,'DEFINE_string(video,"","Use a video file instead of the camera. Use `examples/media/video.avi` for our default"" example video."): flags.hpp'],['../flags_8hpp.html#a7773e867133822f5601899975dc06adb',1,'DEFINE_string(image_dir,"","Process a directory of images. Use `examples/media/` for our default example folder with 20"" images. Read all standard formats (jpg, png, bmp, etc.)."): flags.hpp'],['../flags_8hpp.html#a5db17b8bc6df4fe40b556af7157dcbf7',1,'DEFINE_string(ip_camera,"","String with the IP camera URL. It supports protocols like RTSP and HTTP."): flags.hpp'],['../flags_8hpp.html#aff61246512375ff5941dc4110e127ca3',1,'DEFINE_string(camera_parameter_folder,"models/cameraParameters/flir/","String with the folder where the camera parameters are located."): flags.hpp'],['../flags_8hpp.html#a9ab689ebe20a261b20587af79123e79a',1,'DEFINE_string(model_folder,"models/","Folder path (absolute or relative) where the models (pose, face, ...) are located."): flags.hpp'],['../flags_8hpp.html#a85be61a31eaa438a7e9c7d2baf51da47',1,'DEFINE_string(output_resolution,"-1x-1","The image resolution (display and output). Use \"-1x-1\" to force the program to use the"" input image resolution."): flags.hpp'],['../flags_8hpp.html#a055e1e0a1618e96f156f32278b41d3e4',1,'DEFINE_string(model_pose,"BODY_25","Model to be used. E.g., `COCO` (18 keypoints), `MPI` (15 keypoints, ~10% faster), ""`MPI_4_layers` (15 keypoints, even faster but less accurate)."): flags.hpp'],['../flags_8hpp.html#a66d6d5c07371179c3702dbd1da9d9bd3',1,'DEFINE_string(net_resolution,"-1x368","Multiples of 16. If it is increased, the accuracy potentially increases. If it is"" decreased, the speed increases. For maximum speed-accuracy balance, it should keep the"" closest aspect ratio possible to the images or videos to be processed. Using `-1` in"" any of the dimensions, OP will choose the optimal aspect ratio depending on the user's"" input value. E.g., the default `-1x368` is equivalent to `656x368` in 16:9 resolutions,"" e.g., full HD (1980x1080) and HD (1280x720) resolutions."): flags.hpp'],['../flags_8hpp.html#af5ee5f61f0d36a03bb8647408f5e236b',1,'DEFINE_string(face_net_resolution,"368x368","Multiples of 16 and squared. Analogous to `net_resolution` but applied to the face keypoint"" detector. 320x320 usually works fine while giving a substantial speed up when multiple"" faces on the image."): flags.hpp'],['../flags_8hpp.html#afaf97bbf6a49576782d25147bc865bed',1,'DEFINE_string(hand_net_resolution,"368x368","Multiples of 16 and squared. Analogous to `net_resolution` but applied to the hand keypoint"" detector."): flags.hpp'],['../flags_8hpp.html#a7a3597e9216885470199ca1578eb7f69',1,'DEFINE_string(write_images,"","Directory to write rendered frames in `write_images_format` image format."): flags.hpp'],['../flags_8hpp.html#a6957bf419a0ca3478948a62a3ce5ecf0',1,'DEFINE_string(write_images_format,"png","File extension and format for `write_images`, e.g., png, jpg or bmp. Check the OpenCV"" function cv::imwrite for all compatible extensions."): flags.hpp'],['../flags_8hpp.html#a3051d21eb51cc39eed5f781d8eaed960',1,'DEFINE_string(write_video,"","Full file path to write rendered frames in motion JPEG video format. It might fail if the"" final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"" `camera_fps` controls FPS."): flags.hpp'],['../flags_8hpp.html#a9aa48b2ab293842bc42b96df9e97c9b8',1,'DEFINE_string(write_json,"","Directory to write OpenPose output in JSON format. It includes body, hand, and face pose"" keypoints (2-D and 3-D), as well as pose candidates (if `--part_candidates` enabled)."): flags.hpp'],['../flags_8hpp.html#a26d1c7340fc87d4593dda754d54145a2',1,'DEFINE_string(write_coco_json,"","Full file path to write people pose data with JSON COCO validation format."): flags.hpp'],['../flags_8hpp.html#ac6c2099e630e05f867ee10b43f35dc65',1,'DEFINE_string(write_coco_foot_json,"","Full file path to write people foot pose data with JSON COCO validation format."): flags.hpp'],['../flags_8hpp.html#aa3fe7c4c07492e6553a6c2d25ebd76b4',1,'DEFINE_string(write_heatmaps,"","Directory to write body pose heatmaps in PNG format. At least 1 `add_heatmaps_X` flag"" must be enabled."): flags.hpp'],['../flags_8hpp.html#a242473077549869f06534e8a9ea1ddd6',1,'DEFINE_string(write_heatmaps_format,"png","File extension and format for `write_heatmaps`, analogous to `write_images_format`."" For lossless compression, recommended `png` for integer `heatmaps_scale` and `float` for"" floating values."): flags.hpp'],['../flags_8hpp.html#ad8c5173beb83c0f9996362b3a3fba820',1,'DEFINE_string(write_keypoint,"","(Deprecated, use `write_json`) Directory to write the people pose keypoint data. Set format"" with `write_keypoint_format`."): flags.hpp'],['../flags_8hpp.html#a5aaba99bdb163516d0297d2e09dd0c7d',1,'DEFINE_string(write_keypoint_format,"yml","(Deprecated, use `write_json`) File extension and format for `write_keypoint`: json, xml,"" yaml & yml. Json not available for OpenCV < 3.0, use `write_json` instead."): flags.hpp'],['../flags_8hpp.html#ad7a48143249d608e2ad3a8413eb19c34',1,'DEFINE_string(write_video_adam,"","Experimental, not available yet. E.g., `~/Desktop/adamResult.avi`. Flag `camera_fps`"" controls FPS."): flags.hpp'],['../flags_8hpp.html#a72c09e09c94b67f88b53e1a94e7bfe0f',1,'DEFINE_string(write_bvh,"","Experimental, not available yet. E.g., `~/Desktop/mocapResult.bvh`."): flags.hpp'],['../flags_8hpp.html#a63936bd2bc53a453ba74066289ab9d29',1,'DEFINE_string(udp_host,"","Experimental, not available yet. IP for UDP communication. E.g., `192.168.0.1`."): flags.hpp'],['../flags_8hpp.html#aa7b1c758c6d6e35c3227994a9ced0236',1,'DEFINE_string(udp_port,"8051","Experimental, not available yet. Port number for UDP communication."): flags.hpp']]], + ['define_5fstring',['DEFINE_string',['../flags_8hpp.html#a9e7b1394aea185360a1fe19cf4e20a89',1,'DEFINE_string(camera_resolution,"-1x-1","Set the camera resolution (either `--camera` or `--flir_camera`). `-1x-1` will use the"" default 1280x720 for `--camera`, or the maximum flir camera resolution available for"" `--flir_camera`"): flags.hpp'],['../flags_8hpp.html#aab02d4078b5f7999a582d9c5f4248676',1,'DEFINE_string(video,"","Use a video file instead of the camera. Use `examples/media/video.avi` for our default"" example video."): flags.hpp'],['../flags_8hpp.html#a7773e867133822f5601899975dc06adb',1,'DEFINE_string(image_dir,"","Process a directory of images. Use `examples/media/` for our default example folder with 20"" images. Read all standard formats (jpg, png, bmp, etc.)."): flags.hpp'],['../flags_8hpp.html#a5db17b8bc6df4fe40b556af7157dcbf7',1,'DEFINE_string(ip_camera,"","String with the IP camera URL. It supports protocols like RTSP and HTTP."): flags.hpp'],['../flags_8hpp.html#aff61246512375ff5941dc4110e127ca3',1,'DEFINE_string(camera_parameter_folder,"models/cameraParameters/flir/","String with the folder where the camera parameters are located."): flags.hpp'],['../flags_8hpp.html#a9ab689ebe20a261b20587af79123e79a',1,'DEFINE_string(model_folder,"models/","Folder path (absolute or relative) where the models (pose, face, ...) are located."): flags.hpp'],['../flags_8hpp.html#a85be61a31eaa438a7e9c7d2baf51da47',1,'DEFINE_string(output_resolution,"-1x-1","The image resolution (display and output). Use \"-1x-1\" to force the program to use the"" input image resolution."): flags.hpp'],['../flags_8hpp.html#a055e1e0a1618e96f156f32278b41d3e4',1,'DEFINE_string(model_pose,"BODY_25","Model to be used. E.g., `COCO` (18 keypoints), `MPI` (15 keypoints, ~10% faster), ""`MPI_4_layers` (15 keypoints, even faster but less accurate)."): flags.hpp'],['../flags_8hpp.html#a66d6d5c07371179c3702dbd1da9d9bd3',1,'DEFINE_string(net_resolution,"-1x368","Multiples of 16. If it is increased, the accuracy potentially increases. If it is"" decreased, the speed increases. For maximum speed-accuracy balance, it should keep the"" closest aspect ratio possible to the images or videos to be processed. Using `-1` in"" any of the dimensions, OP will choose the optimal aspect ratio depending on the user's"" input value. E.g., the default `-1x368` is equivalent to `656x368` in 16:9 resolutions,"" e.g., full HD (1980x1080) and HD (1280x720) resolutions."): flags.hpp'],['../flags_8hpp.html#af5ee5f61f0d36a03bb8647408f5e236b',1,'DEFINE_string(face_net_resolution,"368x368","Multiples of 16 and squared. Analogous to `net_resolution` but applied to the face keypoint"" detector. 320x320 usually works fine while giving a substantial speed up when multiple"" faces on the image."): flags.hpp'],['../flags_8hpp.html#afaf97bbf6a49576782d25147bc865bed',1,'DEFINE_string(hand_net_resolution,"368x368","Multiples of 16 and squared. Analogous to `net_resolution` but applied to the hand keypoint"" detector."): flags.hpp'],['../flags_8hpp.html#a7a3597e9216885470199ca1578eb7f69',1,'DEFINE_string(write_images,"","Directory to write rendered frames in `write_images_format` image format."): flags.hpp'],['../flags_8hpp.html#a6957bf419a0ca3478948a62a3ce5ecf0',1,'DEFINE_string(write_images_format,"png","File extension and format for `write_images`, e.g., png, jpg or bmp. Check the OpenCV"" function cv::imwrite for all compatible extensions."): flags.hpp'],['../flags_8hpp.html#a2473e551c10d8627471382b70fbb838e',1,'DEFINE_string(write_video,"","Full file path to write rendered frames in motion JPEG video format. It might fail if the"" final path does not finish in `.avi`. It internally uses cv::VideoWriter. Flag"" `write_video_fps` controls FPS."): flags.hpp'],['../flags_8hpp.html#a9aa48b2ab293842bc42b96df9e97c9b8',1,'DEFINE_string(write_json,"","Directory to write OpenPose output in JSON format. It includes body, hand, and face pose"" keypoints (2-D and 3-D), as well as pose candidates (if `--part_candidates` enabled)."): flags.hpp'],['../flags_8hpp.html#a26d1c7340fc87d4593dda754d54145a2',1,'DEFINE_string(write_coco_json,"","Full file path to write people pose data with JSON COCO validation format."): flags.hpp'],['../flags_8hpp.html#ac6c2099e630e05f867ee10b43f35dc65',1,'DEFINE_string(write_coco_foot_json,"","Full file path to write people foot pose data with JSON COCO validation format."): flags.hpp'],['../flags_8hpp.html#aa3fe7c4c07492e6553a6c2d25ebd76b4',1,'DEFINE_string(write_heatmaps,"","Directory to write body pose heatmaps in PNG format. At least 1 `add_heatmaps_X` flag"" must be enabled."): flags.hpp'],['../flags_8hpp.html#a242473077549869f06534e8a9ea1ddd6',1,'DEFINE_string(write_heatmaps_format,"png","File extension and format for `write_heatmaps`, analogous to `write_images_format`."" For lossless compression, recommended `png` for integer `heatmaps_scale` and `float` for"" floating values."): flags.hpp'],['../flags_8hpp.html#ad8c5173beb83c0f9996362b3a3fba820',1,'DEFINE_string(write_keypoint,"","(Deprecated, use `write_json`) Directory to write the people pose keypoint data. Set format"" with `write_keypoint_format`."): flags.hpp'],['../flags_8hpp.html#a5aaba99bdb163516d0297d2e09dd0c7d',1,'DEFINE_string(write_keypoint_format,"yml","(Deprecated, use `write_json`) File extension and format for `write_keypoint`: json, xml,"" yaml & yml. Json not available for OpenCV < 3.0, use `write_json` instead."): flags.hpp'],['../flags_8hpp.html#a26f9e4bae967b528e221c40d21cad543',1,'DEFINE_string(write_video_adam,"","Experimental, not available yet. E.g., `~/Desktop/adamResult.avi`. Flag `write_video_fps`"" controls FPS."): flags.hpp'],['../flags_8hpp.html#a72c09e09c94b67f88b53e1a94e7bfe0f',1,'DEFINE_string(write_bvh,"","Experimental, not available yet. E.g., `~/Desktop/mocapResult.bvh`."): flags.hpp'],['../flags_8hpp.html#a63936bd2bc53a453ba74066289ab9d29',1,'DEFINE_string(udp_host,"","Experimental, not available yet. IP for UDP communication. E.g., `192.168.0.1`."): flags.hpp'],['../flags_8hpp.html#aa7b1c758c6d6e35c3227994a9ced0236',1,'DEFINE_string(udp_port,"8051","Experimental, not available yet. Port number for UDP communication."): flags.hpp']]], ['define_5fuint64',['DEFINE_uint64',['../flags_8hpp.html#a89127a571b2b18ba05912d7b06ffb2ef',1,'DEFINE_uint64(frame_first, 0,"Start on desired frame number. Indexes are 0-based, i.e., the first frame has index 0."): flags.hpp'],['../flags_8hpp.html#a22572531e5a4896c510639ac57cf522c',1,'DEFINE_uint64(frame_step, 1,"Step or gap between processed frames. E.g., `--frame_step 5` would read and process frames"" 0, 5, 10, etc.."): flags.hpp'],['../flags_8hpp.html#a158227abc2af90abaec523a784b40fa8',1,'DEFINE_uint64(frame_last,-1,"Finish on desired frame number. Select -1 to disable. Indexes are 0-based, e.g., if set to"" 10, it will process 11 frames (0-10)."): flags.hpp']]], ['delete_5fcopy',['DELETE_COPY',['../classop_1_1_face_cpu_renderer.html#a233f2a83930d07e4d420b43c8a660f32',1,'op::FaceCpuRenderer::DELETE_COPY()'],['../classop_1_1_hand_cpu_renderer.html#a66a7d318b240c73687320bf092363409',1,'op::HandCpuRenderer::DELETE_COPY()'],['../classop_1_1_sub_thread_no_queue.html#a43504502c36461305d656fb87b914749',1,'op::SubThreadNoQueue::DELETE_COPY()']]], ['deleter',['Deleter',['../classcl_1_1detail_1_1_deleter.html#a899859732bb1c5f296f3e4f05ca6a39d',1,'cl::detail::Deleter']]], diff --git a/html/search/variables_15.js b/html/search/variables_15.js index ca38e2a0..75f03aa5 100644 --- a/html/search/variables_15.js +++ b/html/search/variables_15.js @@ -1,6 +1,5 @@ var searchData= [ - ['webcamfps',['webcamFps',['../structop_1_1_wrapper_struct_input.html#a49970fa2a3e14394ac49c1f0679c72f5',1,'op::WrapperStructInput']]], ['width',['width',['../structop_1_1_rectangle.html#a0d0ae826039b0961fae8723708809cdf',1,'op::Rectangle']]], ['writebvh',['writeBvh',['../structop_1_1_wrapper_struct_output.html#add74785fc0cb1fc7d2c6b5f88b622d53',1,'op::WrapperStructOutput']]], ['writecocofootjson',['writeCocoFootJson',['../structop_1_1_wrapper_struct_output.html#aaadbe4f8f765a751973ed1b405843c74',1,'op::WrapperStructOutput']]], diff --git a/html/structop_1_1_wrapper_struct_input-members.html b/html/structop_1_1_wrapper_struct_input-members.html index efc36e07..e79a84a9 100644 --- a/html/structop_1_1_wrapper_struct_input-members.html +++ b/html/structop_1_1_wrapper_struct_input-members.html @@ -125,8 +125,7 @@ $(document).ready(function(){initNavTree('structop_1_1_wrapper_struct_input.html
    producerTypeop::WrapperStructInput
    realTimeProcessingop::WrapperStructInput
    undistortImageop::WrapperStructInput
    webcamFpsop::WrapperStructInput
    WrapperStructInput(const ProducerType producerType=ProducerType::None, const std::string &producerString="", const unsigned long long frameFirst=0, const unsigned long long frameStep=1, const unsigned long long frameLast=std::numeric_limits< unsigned long long >::max(), const bool realTimeProcessing=false, const bool frameFlip=false, const int frameRotate=0, const bool framesRepeat=false, const Point< int > &cameraResolution=Point< int >{-1,-1}, const double webcamFps=30., const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=1)op::WrapperStructInput
    WrapperStructInput(const ProducerType producerType=ProducerType::None, const std::string &producerString="", const unsigned long long frameFirst=0, const unsigned long long frameStep=1, const unsigned long long frameLast=std::numeric_limits< unsigned long long >::max(), const bool realTimeProcessing=false, const bool frameFlip=false, const int frameRotate=0, const bool framesRepeat=false, const Point< int > &cameraResolution=Point< int >{-1,-1}, const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=1)op::WrapperStructInput
    diff --git a/html/structop_1_1_wrapper_struct_input.html b/html/structop_1_1_wrapper_struct_input.html index 6f2dc835..0696937f 100644 --- a/html/structop_1_1_wrapper_struct_input.html +++ b/html/structop_1_1_wrapper_struct_input.html @@ -118,8 +118,8 @@ $(document).ready(function(){initNavTree('structop_1_1_wrapper_struct_input.html - - + +

    Public Member Functions

     WrapperStructInput (const ProducerType producerType=ProducerType::None, const std::string &producerString="", const unsigned long long frameFirst=0, const unsigned long long frameStep=1, const unsigned long long frameLast=std::numeric_limits< unsigned long long >::max(), const bool realTimeProcessing=false, const bool frameFlip=false, const int frameRotate=0, const bool framesRepeat=false, const Point< int > &cameraResolution=Point< int >{-1,-1}, const double webcamFps=30., const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=1)
     
     WrapperStructInput (const ProducerType producerType=ProducerType::None, const std::string &producerString="", const unsigned long long frameFirst=0, const unsigned long long frameStep=1, const unsigned long long frameLast=std::numeric_limits< unsigned long long >::max(), const bool realTimeProcessing=false, const bool frameFlip=false, const int frameRotate=0, const bool framesRepeat=false, const Point< int > &cameraResolution=Point< int >{-1,-1}, const std::string &cameraParameterPath="models/cameraParameters/", const bool undistortImage=true, const unsigned int imageDirectoryStereo=1)
     
    @@ -143,8 +143,6 @@ Public Attributes - - @@ -155,7 +153,7 @@ Public Attributes

    Detailed Description

    WrapperStructInput: Input (images, video, webcam, etc.) configuration struct. WrapperStructInput allows the user to set up the input frames generator.

    Constructor & Destructor Documentation

    - +

    Public Attributes

     
    Point< int > cameraResolution
     
    double webcamFps
     
    std::string cameraParameterPath
     
    bool undistortImage
    @@ -219,12 +217,6 @@ Public Attributes - - - - - - @@ -422,19 +414,6 @@ Public Attributes

    Whether to undistort the image given the camera parameters.

    -
    - - -
    -
    -
    const Point< int > &  cameraResolution = Point< int >{-1,-1},
    const double webcamFps = 30.,
    - - - -
    double op::WrapperStructInput::webcamFps
    -
    -

    Frame rate of the camera (only for some producers).

    -

    The documentation for this struct was generated from the following file: